import {
	useQuery,
	useMutation,
	useQueryClient,
	QueryClient,
	QueryClientProvider,
} from '@tanstack/react-query'
import {
	createHashRouter,
	RouterProvider,
	useNavigate
} from "react-router-dom";
import Tasks from "./Tasks";
import Projects from "./Projects";
import TaskDetail from "./TaskDetail";
import ProjectDetail from "./ProjectDetail";
import ClientDetail from "./ClientDetail";
import Navigation from "./Navigation";
import Clients from "./Clients";
import Layout from "./Layout";
import TimeEntries from "./TimeEntries";
import {ToastContainer} from "react-toastify";
import 'react-toastify/dist/ReactToastify.css';
import { ReactQueryDevtools } from '@tanstack/react-query-devtools'
import Documents from "./Documents";
import DocumentDetail from "./DocumentDetail";
import 'react-tabs/style/react-tabs.css';

const queryClient = new QueryClient()
const router = createHashRouter([
	{
		path: "/",
		element: <Layout/>,
		children: [
			{
				path: "project",
				element: <Projects/>,
			},
			{
				path: "project/:id",
				element: <ProjectDetail/>,
			},
			{
				path: "project/:id/*",
				element: <ProjectDetail/>,
			},
			{
				path: "client",
				element: <Clients/>,
			},
			{
				path: "client/:id",
				element: <ClientDetail/>,
			},
			{
				path: "client/:id/*",
				element: <ClientDetail/>,
			},
			{
				path: "document",
				element: <Documents/>,
			},
			{
				path: "document/:id",
				element: <DocumentDetail/>,
			},
			{
				path: "task",
				element: <Tasks/>,
			},
			{
				path: "time-entry",
				element: <TimeEntries/>,
			},
			{
				path: "task/:task_id",
				element: <TaskDetail/>,
			},
			{
				path: "task/:task_id/*",
				element: <TaskDetail/>,
			},
		],
	},

]);
const App = () => {
	return <QueryClientProvider client={queryClient}>
		<React.StrictMode>
			<RouterProvider router={router}/>
		</React.StrictMode>
		<ToastContainer/>
		<ReactQueryDevtools initialIsOpen={false} />
	</QueryClientProvider>;
}
export default App;
