import React, {useState, useEffect, useRef} from "react";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import IconButton from "@mui/material/IconButton";
import DeleteIcon from "@mui/icons-material/Delete";
import ListItemButton from "@mui/material/ListItemButton";
import ListItemIcon from "@mui/material/ListItemIcon";
import ListSubheader from '@mui/material/ListSubheader';
import Checkbox from "@mui/material/Checkbox";
import ListItemText from "@mui/material/ListItemText";
import InputBase from "@mui/material/InputBase";
import Button from "@mui/material/Button";
import AddCircleIcon from '@mui/icons-material/AddCircle';

const Checklist = ({checklist, mutate}) => {
	const [items, setItems] = useState(checklist);
	const [newItem, setNewItem] = useState('');
	const isMounted = useRef(true);

	useEffect(() => {
		if (isMounted.current) {
			// This code only runs after the first render
			isMounted.current = false;
		} else {
			console.log('Updated items:', items);
			mutate({checklist: items})
		}
	}, [items]); // This useEffect runs whenever the 'items' state changes

	const addItem = () => {
		if (newItem.trim() !== '') {
			setItems([...items, {label: newItem, checked: false}]);
			setNewItem('');
		}
	};

	const deleteItem = (index) => {
		const updatedItems = [...items];
		updatedItems.splice(index, 1);
		setItems(updatedItems);
	};

	const handleToggle = (index) => () => {
		const updatedItems = [...items];
		updatedItems[index].checked = !updatedItems[index].checked;
		setItems(updatedItems);
	};

	const handleEnterKeyPress = (e) => {
		if (e.key === 'Enter' ) {
			addItem();
		}
	};

	return (<>
		<List sx={{width: '100%', maxWidth: 500, mt:2}}
			  dense='true'
			  subheader={<ListSubheader sx={{lineHeight:2}}>Checklist</ListSubheader>}
		>
			{items && items.map((item, index) => {
				const labelId = `checkbox-list-label-${index}`;

				return (
					<ListItem
						key={index}
						sx={[
							{py:0},
							{'& .MuiButtonBase-root': {py:'3px'}},
							{'& .MuiListItemSecondaryAction-root': {opacity:0}},
							{'&:hover .MuiListItemSecondaryAction-root': {opacity:1}}
						]}
						secondaryAction={
							<IconButton
								edge="end"
								aria-label="delete"
								onClick={() => deleteItem(index)}
							>
								<DeleteIcon/>
							</IconButton>
						}
						disablePadding
					>
						<ListItemButton role={undefined} onClick={handleToggle(index)}>
							<ListItemIcon sx={{minWidth: 32}}>
								<Checkbox
									edge="start"
									checked={item.checked}
									tabIndex={-1}
									disableRipple
									inputProps={{'aria-labelledby': labelId}}
									onClick={handleToggle(index)}
								/>
							</ListItemIcon>
							<ListItemText id={labelId} primary={item.label} primaryTypographyProps={{fontSize: 16}}/>
						</ListItemButton>
					</ListItem>
				);
			})}
			<ListItem
				key={'add-new'}
				sx={[
					{py:0},
					{'& .MuiButtonBase-root': {py:'3px'}},
				]}
				// secondaryAction={
				// 	<IconButton
				// 		edge="end"
				// 		aria-label="delete"
				// 		onClick={addItem}
				// 	>
				// 		<AddCircleIcon />
				// 	</IconButton>
				// }
				disablePadding
			>
				<ListItemButton role={undefined}>
					<ListItemIcon sx={{minWidth: 32}} onClick={addItem}>
						<AddCircleIcon />
					</ListItemIcon>
					<InputBase sx={{width: '100%'}} placeholder="Add new item"
							   inputProps={{'aria-label': "Add new item"}}
							   value={newItem}
							   onChange={(e) => setNewItem(e.target.value)}
							   onKeyDown={handleEnterKeyPress}
					/>
				</ListItemButton>
			</ListItem>
		</List>
	</>);
}
export default Checklist;
