import React, {useEffect, useState} from "react";
import {useForm} from "react-hook-form"
import {useOutletContext, useParams} from 'react-router-dom';

import {useClient, useCurrentUserData, useProjects, useTasks, useUpdateProject} from "../hooks";
import Projects from "./Projects";
import EditableText from "./EditableText";
import Documents from "./Documents";
import {Tab} from "react-tabs";
import TagSelect from "./TagSelect";
import {ReusableTabs, TabPanel, TabList} from "./Tabs";
import Permissions from "./Permissions";
import PermissionsCheck from "./PermissionsCheck";
import SwitchControlled from "./Form/SwitchControlled";
import Grid from '@mui/material/Grid';
import Box from '@mui/material/Box';
import InputText from "./Form/InputText";
import Paper from '@mui/material/Paper';
import InputAdornment from '@mui/material/InputAdornment';
import CircularProgress from '@mui/material/CircularProgress';
import Avatar from '@mui/material/Avatar';
import PersonIcon from '@mui/icons-material/Person';
import {toHoursAndMinutes} from "./TimeEntries";
import ListItemButton from "@mui/material/ListItemButton";
import ListItemIcon from "@mui/material/ListItemIcon";
import BookmarkIcon from "@mui/icons-material/Bookmark";
import ListItemText from "@mui/material/ListItemText";
import AccessTimeIcon from '@mui/icons-material/AccessTime';
import Button from "@mui/material/Button";
import SupportTimeProgress from "./SupportTimeProgress";

function getFirstDayOfMonth() {
	const date = new Date();
	return new Date(date.getFullYear(), date.getMonth(), 1);
}

const ProjectDetail = (props) => {
	let {id} = useParams();
	id = parseInt(id);
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
	} = useForm()
	const [DocumentsShown, setDocumentsShown] = useState(false);
	const {isInternal, isAdmin, query: userQuery, item: user} = useCurrentUserData();
	const {item, query: projectQuery, mutate} = useClient({id: id});
	const {setHeader, setBreadcrumbsRoute, setActiveMenuItem} = useOutletContext();
	useEffect(() => {
		if (item) {
			setHeader(() => () => <>{item.title}</>);
			setBreadcrumbsRoute([
				{'label': 'Clients', 'link': '/client'},
				{'label': `${item.title}`}
			]);
			setActiveMenuItem({client: id});
		}

	}, [item]);


	return (item && <PermissionsCheck object_type="client" object_id={id} role="reader" showErrorMessage={true}>
			{projectQuery.isLoading || userQuery.isLoading ? 'Loading' : <>
				<Paper sx={{p: 2, mb: 2}}>
					<Grid container spacing={3}>
						<Grid item xs="auto">
							<Avatar>
								<PersonIcon/>
							</Avatar>
							<Box sx={{mt: 3, position: 'relative'}}>
								<AccessTimeIcon color="primary" sx={{mx: 1, mb: 1}}/>
								<SupportTimeProgress client_id={id} support={item.support} detailView={true}/>
							</Box>
						</Grid>
						<Grid item xs={7}>
							<h2>
								<PermissionsCheck object_type="client" object_id={id} role={'editor'}
												  noPermissionContent={<>{item.title}</>}>
									<EditableText
										label={'Title'}
										text={item.title}
										onChange={value => mutate({title: value})}
									/></PermissionsCheck>
							</h2>
							<PermissionsCheck object_type="client" object_id={id} role={'editor'}
											  noPermissionContent={<>{item.description}</>}>
								<EditableText
									label={'Description'}
									text={item.description}
									onChange={value => mutate({description: value})}
								/>
							</PermissionsCheck>
						</Grid>
						<Grid item xs>
							<TagSelect
								object_id={id}
								object_type={'client'}
								initialValue={item.tags}
							/>
							<PermissionsCheck object_type="client" object_id={id} role={'editor'}
											  noPermissionContent={<>{item.support}</>}>
								<Box sx={{maxWidth: 100, display: 'inline-flex'}}>
									<EditableText
										label={'Support'}
										text={item.support}
										onChange={value => mutate({support: value})}
									/>
								</Box>
							</PermissionsCheck>
							<PermissionsCheck object_type="client" object_id={id} role={'editor'}>
								{
									(isInternal || isAdmin) && <SwitchControlled
										onChange={value => mutate({internal: value ? 1 : 0})}
										label={'Internal'}
										defaultValue={item.internal}
									/>}
							</PermissionsCheck>
							<PermissionsCheck object_type="client" object_id={id} role={'editor'}>
								{(isAdmin || item.user_id === user.id) && <SwitchControlled
									onChange={value => mutate({private: value ? 1 : 0})}
									label={'Private'}
									defaultValue={item.private}
								/>}
							</PermissionsCheck>
						</Grid>
					</Grid>
				</Paper>
				<ReusableTabs>
					<TabList>
						<Tab id="projects">Projects</Tab>
						<Tab id="documents">Documents</Tab>
						<Tab id="permissions">Permissions</Tab>
					</TabList>

					<TabPanel>
						<Projects
							client_id={id}
							show_form={false}
						/>
					</TabPanel>
					<TabPanel>
						<Documents object_id={id} object_type={'client'}/>
					</TabPanel>

					<TabPanel>
						<Permissions object_id={id} object_type={'client'}/>
					</TabPanel>

				</ReusableTabs>
			</>}
		</PermissionsCheck>
	)
}
export default ProjectDetail;
