import {useNavigate} from "react-router-dom";
import {MaterialReactTable} from 'material-react-table';
import {useClients, useProjects} from "../hooks";
import React, {useMemo, useRef, useState, useEffect} from "react";
import FormNewClient from "./FormNewClient";
import Table from "./Table";
import Paper from '@mui/material/Paper';
import Button from '@mui/material/Button';
import TagLabel from "./TagLabel";
import apiFetch from "@wordpress/api-fetch";
import {useQueryClient} from "@tanstack/react-query";
import {useOutletContext} from "react-router-dom";
import AddCircleOutlineIcon from '@mui/icons-material/AddCircleOutline';

const Clients = () => {
	const tableInstanceRef = useRef(null) //ts
	const [addNewFormShown, setAddNewFormShown] = useState(false);
	const queryClient = useQueryClient();
	const navigate = useNavigate();
	const {setHeader, setBreadcrumbsRoute} = useOutletContext();
	useEffect(() => {
		setHeader(() => () => <>Clients</>);
		setBreadcrumbsRoute([{'label': 'Clients'}]);
	}, []);

	const columns = useMemo(
		() => [
			{
				header: 'Title',
				accessorFn: (row) => {
					return <span className="cursor-pointer"
								 onClick={() => navigate(`/client/${row.id}`)}>{row.title}</span>;
				},
			},
			{
				header: 'Description',
				accessorKey: 'description',
			},
			{
				header: 'Tags',
				accessorFn: (row, index, returnString) => {
					if (!row.tags.length) {
						return '';
					}
					return row.tags.map(item => <TagLabel tag={item}/>);
				},
			},
		],
		[],
	);
	const {deleteItems, items, query} = useClients();

	if (query.isLoading) {
		return 'Loading';
	}
	return (
		<>
			{addNewFormShown && <Paper sx={{p: 2, mb: 2}}>
				<FormNewClient/>
			</Paper> }

			<Table
				data={items}
				ToolbarActions={<Button variant="contained" size="small" startIcon={<AddCircleOutlineIcon/>}
										onClick={() => setAddNewFormShown(!addNewFormShown)}>Add new client</Button>}
				deleteItems={deleteItems}
				columns={columns}
				tableInstanceRef={tableInstanceRef}
				enableRowOrdering={true}
				onDragEnd={(table) => {
					const {draggingRow, hoveredRow} = table.getState();
					if (hoveredRow && draggingRow) {
						items.splice(
							hoveredRow.index,
							0,
							items.splice(draggingRow.index, 1)[0],
						);
						apiFetch({
							path: `/wpify-erp/v1/client/order-index`,
							method: 'POST',
							data: {
								items
							}
						}).then((result) => {
							queryClient.setQueryData(['clients'], result);

						})
					}
				}}
			/>
		</>

	);
}
export default Clients;
