import { SortableContext, useSortable } from "@dnd-kit/sortable"
import { CSS } from "@dnd-kit/utilities"
import { useMemo, useState } from "react"
import TaskCard from "./TaskCard"

function ColumnContainer({
							 column,
							 deleteColumn,
							 updateColumn,
							 createTask,
							 tasks,
							 deleteTask,
							 updateTask
						 }) {
	const [editMode, setEditMode] = useState(false)

	const tasksIds = useMemo(() => {
		return tasks.map(task => task.id)
	}, [tasks])

	const {
		setNodeRef,
		attributes,
		listeners,
		transform,
		transition,
		isDragging
	} = useSortable({
		id: column.id,
		data: {
			type: "Column",
			column
		},
		disabled: editMode
	})

	const style = {
		transition,
		transform: CSS.Transform.toString(transform)
	}

	if (isDragging) {
		return (
			<div
				ref={setNodeRef}
				style={style}
				className="
      bg-gray-200
      opacity-40
      border-2
      border-pink-500
      w-[350px]
      h-[500px]
      max-h-[500px]
      rounded-md
      flex
      flex-col
      "
			></div>
		)
	}

	return (
		<div
			ref={setNodeRef}
			style={style}
			className="
  bg-gray-200
  w-[350px]
  h-[500px]
  max-h-[500px]
  rounded-md
  flex
  flex-col
  "
		>
			{/* Column title */}
			<div
				{...attributes}
				{...listeners}
				onClick={() => {
					setEditMode(true)
				}}
				className="
      shadow-3xl
      bg-gray-200
      text-md
      h-[60px]
      cursor-grab
      rounded-md
      rounded-b-none
      p-3
      font-bold
      border-bg-gray-100
      border-4
      flex
      items-center
      justify-between
      "
			>
				<div className="flex gap-2">
					<div
						className="
        flex
        justify-center
        items-center
        bg-gray-100
        px-2
        py-1
        text-sm
        rounded-full
        "
					>
						{tasks.length}
					</div>
					{column.title}

				</div>
			</div>

			{/* Column task container */}
			<div className="flex flex-grow flex-col gap-4 p-2 overflow-x-hidden overflow-y-auto">
				<SortableContext items={tasksIds}>
					{tasks.map(task => (
						<TaskCard
							key={task.id}
							task={task}
							deleteTask={deleteTask}
							updateTask={updateTask}
						/>
					))}
				</SortableContext>
			</div>
			{/* Column footer */}
			<button
				className="flex gap-2 items-center border-bg-gray-100 border-2 rounded-md p-4 border-x-bg-gray-100 hover:bg-black hover:text-rose-500 active:bg-black"
				onClick={() => {
					createTask(column.id)
				}}
			>
				Add task
			</button>
		</div>
	)
}

export default ColumnContainer
