import React, {useEffect, useState} from "react";
import {useForm} from "react-hook-form"
import {useOutletContext, useParams} from 'react-router-dom';

import {useDocument} from "../hooks";
import FormNewDocument from "./FormNewDocument";
import TagSelect from "./TagSelect";
import Paper from '@mui/material/Paper';
import Grid from "@mui/material/Grid";
import DescriptionIcon from '@mui/icons-material/Description';

const DocumentDetail = (props) => {

	let {id} = useParams();
	id = parseInt(id);
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
	} = useForm()
	const [notesShown, setNotesShown] = useState(false);
	const {item, query, mutate} = useDocument({id});
	const {setHeader, setBreadcrumbsRoute, setActiveMenuItem} = useOutletContext();
	useEffect(() => {
		if (item) {
			setHeader(() => () => <>{item.title}</>);
			setBreadcrumbsRoute([
				{'label': 'Documents', 'link': '/document' },
				{'label': `${item.object_type} ${item.object_id}`, 'link': `/${item.object_type}/${item.object_id}`},
				{'label': `${item.title}`}
			]);
			setActiveMenuItem({document: id});
		}

	}, [item]);

	return (
		<>
			{query.isLoading ? 'Loading' : <>
				<Paper sx={{p: 2, mb: 2}}>
					<Grid container spacing={3} sx={{mb: 2}}>
						<Grid item xs="auto">
							<DescriptionIcon color="action" sx={{fontSize: 46}}/>
						</Grid>
						<Grid item xs>
							<TagSelect
								object_id={item.id}
								object_type={'document'}
								initialValue={item.tags}
							/>
						</Grid>
					</Grid>

					<FormNewDocument
						defaultTitle={item.title}
						defaultContent={item.content}
						object_type={item.object_type}
						object_id={item.object_id}
						document_id={id}
						isPrivate={item.private}
						internal={item.internal}
					/>
				</Paper>
			</>}
		</>
	)
}
export default DocumentDetail;
