import {useNavigate, useOutletContext} from "react-router-dom";
import {useDocuments} from "../hooks";
import React, {useEffect, useMemo, useRef, useState} from "react";
import Table from "./Table";
import FormNewDocument from "./FormNewDocument";
import Paper from '@mui/material/Paper';
import Button from '@mui/material/Button';
import TagLabel from "./TagLabel";
import TagSelect from "./TagSelect";
import PermissionsCheck from "./PermissionsCheck";
import AddCircleOutlineIcon from '@mui/icons-material/AddCircleOutline';

const Documents = ({object_id, object_type, show_form = true}) => {
	const tableInstanceRef = useRef(null) //ts
	const navigate = useNavigate();
	const {items, query, deleteItems} = useDocuments({
		query_params: {
			object_id,
			object_type
		}
	});
	const [addNewFormShown, setAddNewFormShown] = useState(false);

	if (!object_id) {
		const {setHeader, setBreadcrumbsRoute} = useOutletContext();
		useEffect(() => {
			setHeader(() => () => <>Documents</>);
			setBreadcrumbsRoute([{'label': 'Documents' }]);
		}, []);
	}

	const columns = useMemo(
		() => [
			{
				header: 'Title',
				accessorFn: (row) => {
					return <span className="cursor-pointer"
								 onClick={() => navigate(`/document/${row.id}`)}>{row.title}</span>;
				},
			},
			{
				header: 'Object type',
				accessorKey: 'object_type',
			},
			{
				header: 'Object id',
				accessorKey: 'object_id',
			},
			{
				header: 'Tags',
				accessorFn: (row, index, returnString) => {
					if (!row.tags.length) {
						return '';
					}
					if (returnString) {
						return row.tags.map(item => item.title).join(', ');
					}
					return row.tags.map(item => <TagLabel tag={item}/>);
				},
				Edit: ({cell, column, table}) => {
					return <>
						<TagSelect
							object_id={cell.row.original.id}
							object_type={'document'}
							initialValue={cell.row.original.tags}
						/>
					</>
				},
			},
		],
		[items],
	);


	if (query.isLoading) {
		return 'Loading';
	}
	return (
		<PermissionsCheck object_type={object_type} object_id={object_id} showErrorMessage={true} module="document"
						  role="reader">

			{addNewFormShown && <Paper sx={{p: 2, mb: 2}}>
				<FormNewDocument
					object_id={object_id}
					object_type={object_type}
				/>
			</Paper>}


			<Table
				data={items}
				ToolbarActions={<PermissionsCheck role={'editor'} object_type={'project'} module='document'><Button
					variant="contained" size="small" startIcon={<AddCircleOutlineIcon/>}
					onClick={() => setAddNewFormShown(!addNewFormShown)}>Add document</Button></PermissionsCheck>}
				deleteItems={deleteItems}
				columns={columns}
				tableInstanceRef={tableInstanceRef}
			/>
		</PermissionsCheck>

	);
}
export default Documents;
