import Row from "./Row";
import Column from "./Column";
import React from "react";
import {useForm} from "react-hook-form";
import DateSelect from "./Form/DateSelect";
import {format} from "date-fns";
import Button from '@mui/material/Button';
import DatePicker from "./Form/DatePicker";
const Filters = ({onFilter, onClear, children}) => {
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
		reset,
		control,
		setValue,
	} = useForm()

	const onSubmit = data => {
		if (data.date_to) {
			data.date_to = format(new Date(data.date_to),'yyyy-MM-dd 23:59:59');
		}

		onFilter(data);
	}

	const handleLastMonth = () => {
		const date = new Date();
		const firstDay = new Date(date.getFullYear(), date.getMonth() - 1, 1);
		const lastDay = new Date(date.getFullYear(), date.getMonth(), 0);
		setValue('date_from', format(firstDay,'yyyy-MM-dd HH:mm:ss'));
		setValue('date_to', format(lastDay,'yyyy-MM-dd HH:mm:ss'));
		handleSubmit(onSubmit)();
	}
	const handleCurrentMonth = () => {
		const date = new Date();
		const firstDay = new Date(date.getFullYear(), date.getMonth(), 1);
		const lastDay = new Date(date.getFullYear(), date.getMonth() + 1, 0);
		setValue('date_from', format(firstDay,'yyyy-MM-dd HH:mm:ss'));
		setValue('date_to', format(lastDay,'yyyy-MM-dd HH:mm:ss'));
		handleSubmit(onSubmit)();
	}

	return <>
		<form onSubmit={handleSubmit(onSubmit)}>
			<Row>
				<Column>
					<DatePicker
						label="Date from"
						placeholder={"Date"}
						name={"date_from"}
						control={control}
					/>
				</Column>
				<Column>
					<DatePicker
						label="Date to"
						placeholder={"Date"}
						name={"date_to"}
						control={control}
					/>
				</Column>
				<Column>
					<Button type="submit">Filter</Button>
				</Column>
				<Column>
					<Button type="button" onClick={() => {onClear(); reset()}}>Clear</Button>
				</Column>
				<Column>
					<Button type="button" onClick={() => handleLastMonth()}>Last month</Button>
				</Column>
				<Column>
					<Button type="button" onClick={() => handleCurrentMonth()}>Current month</Button>
				</Column>
				{children}
			</Row>
		</form>
	</>
}
export default Filters;
