import {Controller} from "react-hook-form";
import React from "react";
import {format, compareAsc} from 'date-fns'
import {DateTimePicker as Picker} from '@mui/x-date-pickers/DateTimePicker';
import {AdapterDateFns} from '@mui/x-date-pickers/AdapterDateFns'
import {LocalizationProvider} from '@mui/x-date-pickers/LocalizationProvider';
import { renderTimeViewClock } from '@mui/x-date-pickers/timeViewRenderers';
import cs from 'date-fns/locale/cs';
const DateTimePicker = ({
							name,
							type = 'text',
							options,
							placeholder,
							required = false,
							label,
							register,
							onChange,
							defaultValue,
							control
						}) => {
	return <LocalizationProvider dateAdapter={AdapterDateFns} adapterLocale={cs}>
		<label className="block text-gray-700 text-sm font-bold mb-2" htmlFor={name}>
			{label}
		</label>
		<Controller
			name={name}
			control={control}
			placeholder={placeholder}
			defaultValue={defaultValue}
			render={({field}) => {
				return <Picker
					selected={field.value ? new Date(field.value) : null}
					onChange={(date) => {
						field.onChange(format(date, 'yyyy-MM-dd HH:mm:ss'))
					}}
					ref={field.ref}
					placeholder={label}
					defaultValue={defaultValue}
					viewRenderers={{
						hours: renderTimeViewClock,
						minutes: renderTimeViewClock,
						seconds: null,
					}}
					required={required}
				/>
			}
			}
		/>
	</LocalizationProvider>
}

export default DateTimePicker;
