import {useForm} from "react-hook-form"

import {useClients, useCreateClient, useCreateProject, useCurrentUserData} from "../hooks";
import InputText from "./Form/InputText";
import Button from '@mui/material/Button';
import Stack from '@mui/material/Stack';
import Switch from "./Form/Switch";

const FormNewClient = () => {
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
		reset,
		control
	} = useForm()

	const {create} = useClients();

	const onSubmit = data => {
		data.internal = data.internal ? 1 : 0;
		data.private = data.private ? 1 : 0;
		create(data)
	}

	const {isInternal, isAdmin, query} = useCurrentUserData();

	if (query.isLoading) {
		return 'Loading';
	}

	return (
		/* "handleSubmit" will validate your inputs before invoking "onSubmit" */
		<form onSubmit={handleSubmit(onSubmit)}>
			<Stack
				direction="row"
				spacing={3}
			>
				<InputText
					label="Title"
					register={register}
					name="title"
					required={true}
					control={control}
				/>
				<InputText
					label="Description"
					register={register}
					name="description"
					control={control}
				/>

				{
					(isInternal || isAdmin) && <Switch
						label="Internal"
						register={register}
						name="internal"
						control={control}
					/>
				}
				<Switch
					label="Private"
					register={register}
					name="private"
					control={control}
				/>
				<Button variant="outlined" type="submit">Create client</Button>
			</Stack>
		</form>
	)
}
export default FormNewClient;
