import {useForm} from "react-hook-form"
import {useDocuments, useDocument, useCurrentUserData} from "../hooks";
import {useNavigate} from "react-router-dom";
import Select from "./Form/Select";
import React, {useState} from "react";
import InputText from "./Form/InputText";
import Button from '@mui/material/Button';
import Editor from "./Form/Editor";
import {useQueryClient} from "@tanstack/react-query";
import Switch from "./Form/Switch";
import Paper from '@mui/material/Paper';
import Stack from '@mui/material/Stack';

const FormNewDocument = ({object_id, object_type, defaultTitle, document_id, defaultContent, isPrivate, internal}) => {
	const navigate = useNavigate();
	const {
		register,
		handleSubmit,
		watch,
		reset,
		formState: {errors},
		control
	} = useForm()

	const queryClient = useQueryClient();
	const [content, setContent] = useState('');
	const {isInternal, isAdmin, query} = useCurrentUserData();

	console.log(content);
	const onCreateSuccess = (data) => {
		queryClient.invalidateQueries({
			queryKey: ['documents', {
				object_id,
				object_type
			}]
		})
		reset();
	}
	const {create} = useDocuments({
		onCreateSuccess
	});
	const {mutate} = useDocument({
		id: document_id
	});
	const onSubmit = data => {
		data.object_id = parseInt(data.object_id);
		data.content = content;
		data.internal = data.internal ? 1 : 0;
		data.private = data.private ? 1 : 0;
		if (!document_id) {
			create(data)
		} else {
			data.id = document_id;
			mutate(data);
		}
	}

	return (
		/* "handleSubmit" will validate your inputs before invoking "onSubmit" */
		<form onSubmit={handleSubmit(onSubmit)}>
			<Stack
				direction="column"
				spacing={2}
			>
				<InputText
					defaultValue={defaultTitle}
					placeholder={"Title"}
					name={"title"}
					register={register}
					required={true}
					control={control}
					label={"Title"}
				/>
				<Editor
					initialValue={defaultContent}
					onChange={content => setContent(content)}
					value={content}
				/>
				<Stack
					direction="row"
					spacing={3}
				>
					{
						(isInternal || isAdmin) && <Switch
							label="Internal"
							register={register}
							name="internal"
							control={control}
							defaultValue={internal}
						/>
					}

					<Switch
						label="Private"
						register={register}
						name="private"
						control={control}
						defaultValue={isPrivate}
					/>
					<input {...register('object_type')} type="hidden" value={object_type}/>
					<input {...register('object_id')} type="hidden" value={object_id}/>

					<Button variant="outlined"
							type="submit">{document_id ? "Update document" : "Create document"}</Button>
				</Stack>
			</Stack>
		</form>
	)
}
export default FormNewDocument;
