import {useForm} from "react-hook-form"

import {useClients, useCreateProject, useEnums, usePermissions, useProjects, useUsers} from "../hooks";
import React, {useState} from "react";
import InputText from "./Form/InputText";
import Select from "./Form/Select";
import Button from '@mui/material/Button';
import {useQueryClient} from "@tanstack/react-query";
import Stack from '@mui/material/Stack';

const FormNewPermission = ({object_id, object_type}) => {
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
		reset,
		control
	} = useForm()

	const {createAsync} = usePermissions();
	const {options: userOptions, items: users, query} = useUsers();
	const {items: enums, query: enumsQuery} = useEnums();

	const queryClient = useQueryClient();

	const onSubmit = data => {
		data.user_id = parseInt(data.user_id.value);
		data.object_id = parseInt(data.object_id);
		data.role = data.role.value;
		for (const [key, value] of Object.entries(data.context.modules)) {
			data.context.modules[key].role = data.context.modules[key].role ? data.context.modules[key].role.value : '';
		}

		createAsync(data).then(() => queryClient.invalidateQueries({queryKey: ['permissions', {object_id}]}))
	}

	if (query.isLoading || enumsQuery.isLoading) {
		return 'Loading'
	}
	return (
		/* "handleSubmit" will validate your inputs before invoking "onSubmit" */
		<form onSubmit={handleSubmit(onSubmit)}>
			<Stack
				direction="row"
				spacing={3}
				sx={{mb: 2}}
			>
				<Select
					placeholder={'Select user'}
					options={userOptions}
					control={control}
					name={'user_id'}
					label={'User'}
					required={true}
				/>
				<Select
					placeholder={'Role'}
					options={enums.roles}
					control={control}
					name={'role'}
					label={'Role'}
					required={true}
				/>
			</Stack>
			<Stack
				direction="row"
				spacing={3}
				sx={{mb: 2}}
			>
				{
					enums.modules.map(module => {
						return <>
							<div>
								<h4>Module {module.label}</h4>
								<Select
									placeholder={'Role'}
									options={enums.roles}
									control={control}
									name={`context[modules][${module.value}][role]`}
									label={'Role'}
								/>
							</div>
						</>
					})
				}

			</Stack>
			<input type="hidden" {...register('object_id')} value={object_id}/>
			<input type="hidden" {...register('object_type')} value={object_type}/>
			<Button variant="outlined" type="submit">Add permission</Button>
		</form>
	)
}
export default FormNewPermission;
