import {useForm} from "react-hook-form"

import {useClients, useCreateProject, useCurrentUserData, useProjects} from "../hooks";
import React, {useState} from "react";
import InputText from "./Form/InputText";
import Select from "./Form/Select";
import Button from '@mui/material/Button';
import {useQueryClient} from "@tanstack/react-query";
import Switch from "./Form/Switch";
import Paper from '@mui/material/Paper';
import Stack from '@mui/material/Stack';

const FormNewProject = ({client_id}) => {
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
		reset,
		control
	} = useForm()

	const {createAsync} = useProjects();
	const {items, options, query} = useClients();
	const queryClient = useQueryClient();
	const {isInternal, isAdmin, query: userQuery} = useCurrentUserData();
	const onSubmit = data => {
		data.internal = data.internal ? 1 : 0;
		data.private = data.private ? 1 : 0;
		data.client_id = data.client_id ? data.client_id.value : null;
		createAsync(data).then(() => queryClient.invalidateQueries({queryKey: ['projects', {client_id}]}))
	}

	if (query.isLoading) {
		return 'Loading'
	}
	return (
		/* "handleSubmit" will validate your inputs before invoking "onSubmit" */
		<form onSubmit={handleSubmit(onSubmit)}>
			<InputText
				register={register}
				name={'name'}
				placeholder={'Name'}
				label={'Name'}
				required={true}
				control={control}
			/>
			<InputText
				register={register}
				name={'description'}
				placeholder={'Description'}
				label={'Description'}
				required={true}
				control={control}
			/>
			<Stack
				direction="row"
				spacing={3}
			>
				<Select
					placeholder={'Select client'}
					options={options}
					control={control}
					name={'client_id'}
					label={'Client'}
					defaultValue={options.find(item => item.value === client_id)}
				/>
				{
					(isInternal || isAdmin) && <Switch
						label="Internal"
						register={register}
						name="internal"
						control={control}
					/>
				}

				<Switch
					label="Private"
					register={register}
					name="private"
					control={control}
				/>
				<Button variant="outlined" type="submit">Create project</Button>
			</Stack>
		</form>
	)
}
export default FormNewProject;
