import {useForm} from "react-hook-form"
import {useClients, useCurrentUserData, useProjects, useTasks} from "../hooks";
import {useNavigate} from "react-router-dom";
import Column from "./Column";
import Select from "./Form/Select";
import Row from "./Row";
import React from "react";
import InputText from "./Form/InputText";
import Button from '@mui/material/Button';
import Switch from "./Form/Switch";

const FormNewTask = ({project_id, client_id}) => {
	const navigate = useNavigate();
	const {
		register,
		handleSubmit,
		watch,
		reset,
		formState: {errors},
		control
	} = useForm()

	const {query: queryClients, options: optionsClients, items: clients} = useClients()
	const {query: queryProjects, options: optionsProjects, items: projects} = useProjects()
	const {isInternal, isAdmin, query} = useCurrentUserData();

	const onSuccess = (data) => {
		navigate(`/task/${data.item.id}`);
		reset();
	}
	const {create} = useTasks(onSuccess);
	const onSubmit = data => {
		data.internal = data.internal ? 1 : 0;
		data.private = data.private ? 1 : 0;
		if (data.client_id) {
			data.client_id = parseInt(data.client_id.value);
		}
		if (data.project_id) {
			data.project_id = parseInt(data.project_id.value);
		}
		create(data)
	}

	if (queryProjects.isLoading || queryClients.isLoading) {
		return 'Loading';
	}
	if (project_id && !client_id) {
		const project = projects.find(item => item.id === project_id);
		if (project) {
			client_id = project.client_id;
		}
	}

	return (
		/* "handleSubmit" will validate your inputs before invoking "onSubmit" */
		<form onSubmit={handleSubmit(onSubmit)}>
					<InputText
						label="Title"
						placeholder={"Title"}
						name={"title"}
						register={register}
						required={true}
						control={control}
					/>
					<InputText
						label="Description"
						placeholder={"Description"}
						name={"description"}
						register={register}
						control={control}
					/>
			<Row>
				<Column>
					<Select
						label="Client"
						options={optionsClients}
						placeholder={"Client"}
						name={"client_id"}
						control={control}
						defaultValue={client_id ? optionsClients.find(item => item.value === client_id) : null}
					/>
				</Column>
				<Column>
					<Select
						label="Project"
						options={optionsProjects}
						placeholder={"Project"}
						name={"project_id"}
						control={control}
						defaultValue={project_id ? optionsProjects.find(item => item.value === project_id) : null}
					/>
				</Column>
				{
					(isInternal || isAdmin) && <Column>
						<Switch
							label="Internal"
							register={register}
							name="internal"
							control={control}
						/>
					</Column>
				}

				<Column>
					<Switch
						label="Private"
						register={register}
						name="private"
						control={control}
					/>
				</Column>
				<Column>
					<Button variant="outlined" type="submit">Create task</Button>
				</Column>
			</Row>


		</form>
	)
}
export default FormNewTask;
