import React, {useState, useEffect, useRef} from "react";
import {useForm} from "react-hook-form"
import {useQueryClient} from '@tanstack/react-query'
import {useCreateTaskComment, useCurrentUserData, useTaskComments, useUsers} from "../hooks";
import {useParams} from "react-router-dom";
import {MentionsInput, Mention} from 'react-mentions'
import {FilePond, registerPlugin} from 'react-filepond'

// Import FilePond styles
import 'filepond/dist/filepond.min.css'
import Button from "./Form/Button";
import Row from "./Row";
import Column from "./Column";
import SwitchControlled from "./Form/SwitchControlled";
import Switch from "./Form/Switch";

const FormNewTask = () => {
	const [text, setText] = useState('');
	const [files, setFiles] = useState([])
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
		reset, control
	} = useForm()

	let {task_id} = useParams();
	const queryClient = useQueryClient()
	const {createAsync} = useTaskComments({
		id: task_id
	});
	const {isInternal, isAdmin, query} = useCurrentUserData();

	const onSubmit = data => {

		data.internal = data.internal ? 1 : 0;
		data.private = data.private ? 1 : 0;
		data.description = text;
		createAsync(data).then(() => {
			setText('');
		})
	}

	const {items: users, query: usersQuery} = useUsers();

	const usersSelect = users ? users.map(item => ({
		display: item.display_name,
		id: item.id
	})) : [];

	if (usersQuery.isLoading) {
		return 'Loading';
	}
	return (
		/* "handleSubmit" will validate your inputs before invoking "onSubmit" */
		<form onSubmit={handleSubmit(onSubmit)}>
			<label htmlFor="message" className="block mb-2 text-sm font-medium text-gray-900 dark:text-white">Add
				Comment</label>
			<MentionsInput
				value={text}
				onChange={e => setText(e.target.value)}
				className="block p-3 h-[200px] w-full text-sm text-gray-900 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500"
			>
				<Mention
					trigger="@"
					data={usersSelect}
					displayTransform={value => {
						const user = users.find(user => user.id == value)
						return user ? `@${user.display_name}` : '';
					}}
					markup='@__display__(__id__)'
					style={{
						backgroundColor: '#cee4e5',
					}}
				/>
			</MentionsInput>
			<FilePond
				server={
					{
						process: {
							url: `/wp-json/wpify-erp/v1/task/${task_id}/attachment?`,
							headers: {
								'X-WP-Nonce': erp.nonce
							},
						}
					}
				}
				files={files}
				onupdatefiles={setFiles}
				allowMultiple={true}
				name="file"
				labelIdle='Drag & Drop your files or <span class="filepond--label-action">Browse</span>'
				onprocessfile={() => {
					queryClient.invalidateQueries({queryKey: ['task']})
				}}
			/>
			<Row>
				{
					(isInternal || isAdmin) && <Column>
						<Switch
							label="Internal"
							control={control}
							name={'internal'}
						/>
					</Column>
				}

				<Column>
					<Switch
						label="Private"
						control={control}
						name={'private'}
					/>
				</Column>
			</Row>
			<Button label={"Submit comment"}></Button>
		</form>
	)
}
export default FormNewTask;
