import {useEffect, useState} from "react";
import * as React from 'react';
import {styled, alpha, createTheme, ThemeProvider} from '@mui/material/styles';
import CssBaseline from '@mui/material/CssBaseline';
import MuiDrawer from '@mui/material/Drawer';
import Box from '@mui/material/Box';
import MuiAppBar from '@mui/material/AppBar';
import Toolbar from '@mui/material/Toolbar';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import Typography from '@mui/material/Typography';
import Tooltip from '@mui/material/Tooltip';
import Divider from '@mui/material/Divider';
import Stack from '@mui/material/Stack';
import IconButton from '@mui/material/IconButton';
import Badge from '@mui/material/Badge';
import {default as MUILink} from '@mui/material/Link';
import InputBase from '@mui/material/InputBase';
import MenuIcon from '@mui/icons-material/Menu';
import SearchIcon from '@mui/icons-material/Search';
import ChevronLeftIcon from '@mui/icons-material/ChevronLeft';
import NotificationsIcon from '@mui/icons-material/Notifications';
import ListItemText from '@mui/material/ListItemText';
import ListItemIcon from '@mui/material/ListItemIcon';
import PeopleAltRoundedIcon from '@mui/icons-material/PeopleAltRounded';
import BookmarksIcon from '@mui/icons-material/Bookmarks';
import LibraryAddCheckIcon from '@mui/icons-material/LibraryAddCheck';
import AccessAlarmIcon from '@mui/icons-material/AccessAlarm';
import DescriptionIcon from '@mui/icons-material/Description';
import Card from '@mui/material/Card';
import CardContent from '@mui/material/CardContent';
import Popover from '@mui/material/Popover';
import InputTextControlled from "./Form/InputTextControlled";
import apiFetch from "@wordpress/api-fetch";
import {useLocation, useNavigate, useOutletContext} from "react-router-dom";
import {Outlet, Link} from "react-router-dom";
import SidebarListMenu from "./SidebarListMenu";
import CustomizedBreadcrumbs from "./Breadcrumbs";
import PersonIcon from "@mui/icons-material/Person";
import BookmarkIcon from "@mui/icons-material/Bookmark";
import AssignmentTurnedInIcon from '@mui/icons-material/AssignmentTurnedIn';


const drawerWidth = 300;

const Search = styled('div')(({theme}) => ({
	position: 'relative',
	borderRadius: theme.shape.borderRadius,
	backgroundColor: alpha(theme.palette.common.white, 0.15),
	'&:hover': {
		backgroundColor: alpha(theme.palette.common.white, 0.25),
	},
	marginRight: theme.spacing(2),
	marginLeft: 0,
	width: '100%',
	[theme.breakpoints.up('sm')]: {
		marginLeft: theme.spacing(3),
		width: 'auto',
	},
}));

const SearchIconWrapper = styled('div')(({theme}) => ({
	padding: theme.spacing(0, 2),
	height: '100%',
	position: 'absolute',
	pointerEvents: 'none',
	display: 'flex',
	alignItems: 'center',
	justifyContent: 'center',
}));

const StyledInputBase = styled(InputBase)(({theme}) => ({
	color: 'inherit',
	'& .MuiInputBase-input': {
		padding: theme.spacing(1, 1, 1, 0),
		// vertical padding + font size from searchIcon
		paddingLeft: `calc(1em + ${theme.spacing(4)})`,
		transition: theme.transitions.create('width'),
		width: '100%',
		[theme.breakpoints.up('sm')]: {
			width: '12ch',
			'&:focus': {
				width: '20ch',
			},
		},
	},
}));

const AppBar = styled(MuiAppBar, {
	shouldForwardProp: (prop) => prop !== 'open',
})(({theme, open}) => ({
	zIndex: theme.zIndex.drawer + 1,
	transition: theme.transitions.create(['width', 'margin'], {
		easing: theme.transitions.easing.sharp,
		duration: theme.transitions.duration.leavingScreen,
	}),
	...(open && {
		marginLeft: drawerWidth,
		width: `calc(100% - ${drawerWidth}px)`,
		transition: theme.transitions.create(['width', 'margin'], {
			easing: theme.transitions.easing.sharp,
			duration: theme.transitions.duration.enteringScreen,
		}),
	}),
}));

const Drawer = styled(MuiDrawer, {shouldForwardProp: (prop) => prop !== 'open'})(
	({theme, open}) => ({
		'& .MuiDrawer-paper': {
			position: 'relative',
			whiteSpace: 'nowrap',
			width: drawerWidth,
			transition: theme.transitions.create('width', {
				easing: theme.transitions.easing.sharp,
				duration: theme.transitions.duration.enteringScreen,
			}),
			boxSizing: 'border-box',
			...(!open && {
				overflowX: 'hidden',
				transition: theme.transitions.create('width', {
					easing: theme.transitions.easing.sharp,
					duration: theme.transitions.duration.leavingScreen,
				}),
				width: theme.spacing(7),
				[theme.breakpoints.up('sm')]: {
					width: theme.spacing(9),
				},
			}),
		},
	}),
);

// TODO remove, this demo shouldn't need to reset the theme.
const defaultTheme = createTheme();

export default function Layout() {
	const [open, setOpen] = React.useState(true);

	const [searchQuery, setSearchQuery] = useState("");
	const [searchResults, setSearchResults] = useState(null)
	const [isSearchOpen, setIsSearchOpen] = useState(false);
	const [Header, setHeader] = useState(null)
	const [breadcrumbsRoute, setBreadcrumbsRoute] = useState([])
	const [activeMenuItem, setActiveMenuItem] = useState(null)
	const [anchorEl, setAnchorEl] = React.useState(null);
	const toggleDrawer = () => {
		setOpen(!open);
	};
	const navigate = useNavigate();
	const location = useLocation();
	const pathArray = location.pathname.split('/');

	// useEffect(() => {
	// 	setBreadcrumbsRoute([]);
	// }, []);

	useEffect(() => {
		const timeOutId = setTimeout(() => handleSearch(searchQuery), 500);
		return () => clearTimeout(timeOutId);
	}, [searchQuery]);

	const handleSearch = () => {
		console.log(searchQuery);
		if (!searchQuery) {
			return;
		}
		apiFetch({
			path: `/wpify-erp/v1/search`,
			method: 'POST',
			data: {
				query: searchQuery
			}
		}).then((result) => {
			setSearchResults(result);
			setIsSearchOpen(true);
		})
	}

	const handleNavigate = (type, id) => {
		navigate(`/${type}/${id}`);
		setIsSearchOpen(false);
	}

	const handleClose = () => {
		setAnchorEl(null);
		setIsSearchOpen(false);
	};

	return (
		<ThemeProvider theme={defaultTheme}>
			<Box sx={{display: 'flex'}}>
				<CssBaseline/>
				<AppBar position="absolute" open={open}>
					<Toolbar
						sx={{
							pr: '24px', // keep right padding when drawer closed
						}}
					>
						<IconButton
							edge="start"
							color="inherit"
							aria-label="open drawer"
							onClick={toggleDrawer}
							sx={{
								marginRight: '36px',
								...(open && {display: 'none'}),
							}}
						>
							<MenuIcon/>
						</IconButton>
						<Typography
							component="h1"
							variant="h6"
							color="inherit"
							noWrap
							sx={{flexGrow: 1}}
						>
							{
								Header && <Header/>
							}
						</Typography>
						<div>
							<Search>
								<SearchIconWrapper>
									<SearchIcon/>
								</SearchIconWrapper>
								<StyledInputBase
									placeholder="Search…"
									inputProps={{'aria-label': 'search'}}
									onChange={e => {
										setSearchQuery(e.target.value);
										setAnchorEl(e.target)
									}}
									value={searchQuery}
								/>

							</Search>
							<Popover
								open={isSearchOpen}
								anchorEl={anchorEl}
								onClose={handleClose}
								anchorOrigin={{
									vertical: 'bottom',
									horizontal: 'right',
								}}
								transformOrigin={{
									vertical: 'top',
									horizontal: 'right',
								}}
							>
								<List dense={1}>
									{
										searchResults && <>
											{
												searchResults.clients.map((item) => <ListItemButton
													onClick={() => handleNavigate('client', item.id)}><ListItemIcon
													sx={{minWidth: 28}}><PersonIcon/></ListItemIcon>
													<MUILink>{item.title}</MUILink>
												</ListItemButton>)
											}
											{
												searchResults.projects.map((item) => <ListItemButton
													onClick={() => handleNavigate('project', item.id)}><ListItemIcon
													sx={{minWidth: 28}}><BookmarkIcon/></ListItemIcon>
													<MUILink>{item.name}</MUILink>
												</ListItemButton>)
											}
											{
												searchResults.tasks.map((item) => <ListItemButton
													onClick={() => handleNavigate('task', item.id)}><ListItemIcon
													sx={{minWidth: 28}}><AssignmentTurnedInIcon/></ListItemIcon>
													<MUILink>{item.title}</MUILink>
												</ListItemButton>)
											}

										</>
									}
								</List>
							</Popover>
						</div>

						<IconButton color="inherit">
							<Badge badgeContent={4} color="secondary">
								<NotificationsIcon/>
							</Badge>
						</IconButton>
					</Toolbar>
				</AppBar>
				<Drawer variant="permanent" open={open}>
					<Toolbar
						sx={{
							display: 'flex',
							alignItems: 'center',
							justifyContent: 'flex-end',
							px: [1],
						}}
					>
						<IconButton onClick={toggleDrawer}>
							<ChevronLeftIcon/>
						</IconButton>
					</Toolbar>
					<Divider/>
					<Stack
						direction="row"
						divider={<Divider orientation="vertical" flexItem/>}
						spacing={0}
					>
						<List
							sx={{width: '100%', maxWidth: 60, bgcolor: 'background.paper'}}
							component="nav"
							aria-labelledby="nested-list"
						>
							<ListItemButton onClick={() => navigate('/client')}>
								<Tooltip title="Clients" placement="right">
									<ListItemIcon sx={{minWidth: 36}}>
										<PeopleAltRoundedIcon color={ pathArray.includes('client') ? 'primary' : 'action' }/>
									</ListItemIcon>
								</Tooltip>
							</ListItemButton>
							<ListItemButton onClick={() => navigate('/project')}>
								<Tooltip title="Projects" placement="right">
									<ListItemIcon sx={{minWidth: 36}}>
										<BookmarksIcon color={ pathArray.includes('project') ? 'primary' : 'action' }/>
									</ListItemIcon>
								</Tooltip>
							</ListItemButton>
							<ListItemButton onClick={() => navigate('/task')}>
								<Tooltip title="Tasks" placement="right">
									<ListItemIcon sx={{minWidth: 36}}>
										<LibraryAddCheckIcon color={ pathArray.includes('task') ? 'primary' : 'action' }/>
									</ListItemIcon>
								</Tooltip>
							</ListItemButton>
							<ListItemButton onClick={() => navigate('/time-entry')}>
								<Tooltip title="Time entries" placement="right">
									<ListItemIcon sx={{minWidth: 36}}>
										<AccessAlarmIcon color={ pathArray.includes('time-entry') ? 'primary' : 'action' }/>
									</ListItemIcon>
								</Tooltip>
							</ListItemButton>
							<ListItemButton onClick={() => navigate('/document')}>
								<Tooltip title="Documents" placement="right">
									<ListItemIcon sx={{minWidth: 36}}>
										<DescriptionIcon color={ pathArray.includes('document') ? 'primary' : 'action' }/>
									</ListItemIcon>
								</Tooltip>
							</ListItemButton>
						</List>
						<SidebarListMenu active={activeMenuItem}/>
					</Stack>
				</Drawer>
				<Box
					component="main"
					sx={{
						backgroundColor: (theme) =>
							theme.palette.mode === 'light'
								? theme.palette.grey[100]
								: theme.palette.grey[900],
						flexGrow: 1,
						height: '100vh',
						overflow: 'auto',
					}}
				>
					<Toolbar/>
					<Box sx={{p: 2,}}>
						{ breadcrumbsRoute && <CustomizedBreadcrumbs route={breadcrumbsRoute}/> }
						<Outlet context={{ setHeader, breadcrumbsRoute, setBreadcrumbsRoute, setActiveMenuItem }}/>
					</Box>
				</Box>
			</Box>
		</ThemeProvider>
	);
}
