import {useNavigate} from "react-router-dom";
import {useEnums, usePermission, usePermissions, useUsers} from "../hooks";
import React, {useMemo, useRef, useState, useEffect, useCallback} from "react";
import Table from "./Table";
import Paper from '@mui/material/Paper';
import Button from '@mui/material/Button';
import FormNewPermission from "./FormNewPermission";
import PermissionsCheck from "./PermissionsCheck";
import SelectControlled from "./Form/SelectControlled";
import AddCircleOutlineIcon from '@mui/icons-material/AddCircleOutline';

const Permissions = ({object_id, object_type, show_form = true}) => {

	const tableInstanceRef = useRef(null) //ts
	const navigate = useNavigate();
	const {items, query, deleteItems} = usePermissions({
		query_params: {
			object_id,
			object_type
		}
	});
	const [addNewFormShown, setAddNewFormShown] = useState(false);
	const {options: userOptions, items: users, query: usersQuery} = useUsers();
	const changedRowData = useRef({});
	const [selectedItem, setSelectedItem] = useState(null);
	const {mutate} = usePermission({id: selectedItem});
	const {items: enums, query: enumsQuery} = useEnums();

	const setupChangedRowData = useCallback(
		() => {
			changedRowData.current = {};
			changedRowData.current.modules = {};

			if (enums) {
				enums.modules.map(item => {
					changedRowData.current.modules[item.value] = {};
				})
			}

		}, [enums]
	)

	useEffect(() => {
		if (enums) {
			setupChangedRowData();
		}
	}, [enums]);

	const columns = useMemo(
		() => [
			{
				header: 'User',
				accessorFn: (row) => {
					const user = users ? users.find(user => user.id === row.user_id) : null;

					return user ? user.email : '';
				},
				Edit: ({cell, column, table}) => {
					const item_id = cell.row.original.user_id;
					const selected = userOptions.find(item => item.value === item_id);
					return <>
						<SelectControlled
							defaultValue={selected}
							onChange={value => {
								const newValue = value ? value.value : null;
								changedRowData.current.user_id = newValue;
							}}
							placeholder={column.header}
							options={userOptions}
						/>
					</>
				},
			},
			{
				header: 'Role',
				accessorKey: 'role',
				Edit: ({cell, column, table}) => {
					const item_id = cell.row.original.role;
					const selected = enums.roles.find(item => item.value === item_id);
					return <>
						<SelectControlled
							defaultValue={selected}
							onChange={value => {
								const newValue = value ? value.value : null;
								changedRowData.current.role = newValue;
							}}
							placeholder={column.header}
							options={enums.roles}
						/>
					</>
				},
			},
			{
				header: 'Object type',
				accessorKey: 'object_type',
				Edit: ({cell, column, table}) => {
					return cell.row.original.object_type;
				},
			},
			{
				header: 'Object id',
				accessorKey: 'object_id',
				Edit: ({cell, column, table}) => {
					return cell.row.original.object_id;
				},
			},
			...(enums ? enums.modules.map(module => {
				const moduleValue = module.value;
				return {
					header: 'Module ' + moduleValue,
					accessorFn: (row) => {
						const role = row.context.modules?.[moduleValue].role ? row.context.modules[moduleValue].role : null;
						if (role) {
							return role;
						}
						return '';
					},
					Edit: ({cell, column, table}) => {
						const item_id = cell.row.original?.context?.modules?.[moduleValue]?.role;
						const selected = enums.roles.find(item => item.value === item_id);
						return <>
							<SelectControlled
								defaultValue={selected}
								onChange={value => {
									const newValue = value ? value.value : null;
									changedRowData.current.modules[moduleValue].role = newValue;
								}}
								placeholder={column.header}
								options={enums.roles}
							/>
						</>
					},
				}
			}) : [])
		],
		[items, users, changedRowData, enums],
	);

	const handleRowEdit = ({exitEditingMode, row, values}) => {
		setSelectedItem(row.original.id);
		const data = changedRowData.current;
		setupChangedRowData();
		mutate(data);
		exitEditingMode();


	};

	if (query.isLoading) {
		return 'Loading';
	}


	return (
		<PermissionsCheck object_type={object_type} object_id={object_id} role={'manager'} showErrorMessage={true}>

			{addNewFormShown && <Paper sx={{p: 2, mb: 2}}>
				<FormNewPermission
					object_id={object_id}
					object_type={object_type}
				/>
			</Paper> }

			<Table
				data={items}
				ToolbarActions={<Button variant="contained" size="small" startIcon={<AddCircleOutlineIcon />} onClick={() => setAddNewFormShown(!addNewFormShown)}>Add permissions</Button>}
				deleteItems={deleteItems}
				columns={columns}
				tableInstanceRef={tableInstanceRef}
				enableEditing={true}
				onEditingRowSave={handleRowEdit}
			/>
		</PermissionsCheck>

	);
}
export default Permissions;
