import React, {useEffect, useState} from "react";
import {useForm} from "react-hook-form"
import {useOutletContext, useParams} from 'react-router-dom';
import {useClients, useCurrentUserData, useProject, useUrlParams} from "../hooks";
import Tasks from "./Tasks";
import EditableText from "./EditableText";
import Documents from "./Documents";
import {Tab} from 'react-tabs';
import TagSelect from "./TagSelect";
import {ReusableTabs, TabPanel, TabList} from "./Tabs";
import PermissionsCheck from "./PermissionsCheck";
import Permissions from "./Permissions";
import SwitchControlled from "./Form/SwitchControlled";
import Grid from '@mui/material/Grid';
import Paper from '@mui/material/Paper';
import BookmarkIcon from '@mui/icons-material/Bookmark';

const ProjectDetail = (props) => {
	const {splat, decodedSplat, params} = useUrlParams();

	let {id} = useParams();
	id = parseInt(id);
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
	} = useForm()

	const {item, query: projectQuery, mutate} = useProject({id});
	const {isInternal, isAdmin, query: userQuery, item: user} = useCurrentUserData();

	const [DocumentsShown, setDocumentsShown] = useState(false);
	const {items: clients, query: clientsQuery} = useClients();
	const {setHeader, setBreadcrumbsRoute, setActiveMenuItem} = useOutletContext();
	useEffect(() => {
		if (item) {
			const client = clients ? clients.find(client => client.id === item.client_id) : null;

			setHeader(() => () => <>{item.name}</>);
			setBreadcrumbsRoute([
				{'label': 'Clients', 'link': '/client'},
				{'label': `${client ? client.title : item.client_id}`, 'link': `/client/${item.client_id}`},
				{'label': `${item.name}`}
			]);
			setActiveMenuItem({client: item.client_id, project: id});
		}

	}, [item]);

	return (
		<>
			{(projectQuery.isLoading || userQuery.isLoading) ? 'Loading' :
				<PermissionsCheck object_type="project" object_id={id} role={'reader'} showErrorMessage={true}>
					<Paper sx={{p: 2, mb: 2}}>
						<Grid container spacing={3}>
							<Grid item xs="auto">
								<BookmarkIcon color="action" sx={{fontSize: 46}}/>
							</Grid>
							<Grid item xs={8}>
								<h2>
									<PermissionsCheck object_type="project" object_id={id} role={'editor'}
													  noPermissionContent={<>{item.name}</>}>
										<EditableText
											label={'Name'}
											text={item.name}
											onChange={value => mutate({name: value})}
										/>
									</PermissionsCheck>
								</h2>

								<PermissionsCheck object_type="project" object_id={id} role={'editor'}
												  noPermissionContent={<>{item.description}</>}>
									<EditableText
										label={'Description'}
										text={item.description}
										onChange={value => mutate({description: value})}
									/>
								</PermissionsCheck>


							</Grid>
							<Grid item xs>
								<TagSelect
									object_id={id}
									object_type={'project'}
									initialValue={item.tags}
								/>

								<PermissionsCheck object_type="client" object_id={id} role={'editor'}>
									{(isInternal || isAdmin) && <SwitchControlled
										onChange={value => mutate({internal: value ? 1 : 0})}
										label={'Internal'}
										defaultValue={item.internal}
									/>}
								</PermissionsCheck>
								<PermissionsCheck object_type="client" object_id={id} role={'editor'}>
									{(isAdmin || item.user_id === user?.id) && <SwitchControlled
										onChange={value => mutate({private: value ? 1 : 0})}
										label={'Private'}
										defaultValue={item.private}
									/>}
								</PermissionsCheck>
							</Grid>
						</Grid>
					</Paper>
					<ReusableTabs>
						<TabList>
							<Tab id="tasks">Tasks</Tab>
							<Tab id="documents">Documents</Tab>
							<Tab id="permissions">Permissions</Tab>
						</TabList>

						<TabPanel>
							<PermissionsCheck object_id={id} object_type={'project'} module='task'
											  showErrorMessage={true} role='reader'>
								<Tasks
									project_id={id}
									client_id={item.client_id}
								/>
							</PermissionsCheck>
						</TabPanel>
						<TabPanel>
							<Documents object_id={id} object_type={'project'}/>
						</TabPanel>
						<TabPanel>
							<Permissions object_id={id} object_type={'project'}/>
						</TabPanel>
					</ReusableTabs>

				</PermissionsCheck>}
		</>
	)
}
export default ProjectDetail;
