import {useNavigate, useOutletContext} from "react-router-dom";
import {useClients, useProjects} from "../hooks";
import React, {useEffect, useMemo, useRef, useState} from "react";
import FormNewProject from "./FormNewProject";
import Table from "./Table";
import Button from '@mui/material/Button';
import Paper from '@mui/material/Paper';
import TagLabel from "./TagLabel";
import TagSelect from "./TagSelect";
import PermissionsCheck from "./PermissionsCheck";
import apiFetch from "@wordpress/api-fetch";
import {useQueryClient} from "@tanstack/react-query";
import AddCircleOutlineIcon from '@mui/icons-material/AddCircleOutline';

const Projects = ({client_id, show_form = true}) => {
	const tableInstanceRef = useRef(null) //ts
	const navigate = useNavigate();
	const {items, query, deleteItems} = useProjects({
		client_id,
	});
	const queryClient = useQueryClient();

	const {items: clients, query: clientsQuery} = useClients();
	const [addNewFormShown, setAddNewFormShown] = useState(false);

	if (!client_id) {
		const {setHeader, setBreadcrumbsRoute} = useOutletContext();
		useEffect(() => {
			setHeader(() => () => <>Projects</>);
			setBreadcrumbsRoute([{'label': 'Projects'}]);
		}, []);
	}

	const columns = useMemo(
		() => [
			{
				header: 'Name',
				accessorFn: (row) => {
					return <span className="cursor-pointer"
								 onClick={() => navigate(`/project/${row.id}`)}>{row.name}</span>;
				},
			},
			{
				header: 'Description',
				accessorKey: 'description',
			},
			{
				header: 'Client',
				accessorFn: (row) => {
					const client = clients ? clients.find(client => client.id === row.client_id) : null;

					return client ? client.title : '';
				}
			},
			{
				header: 'Tags',
				accessorFn: (row, index, returnString) => {
					if (!row.tags.length) {
						return '';
					}
					if (returnString) {
						return row.tags.map(item => item.title).join(', ');
					}
					return row.tags.map(item => <TagLabel tag={item}/>);

				},
				Edit: ({cell, column, table}) => {
					return <>
						<TagSelect
							object_id={cell.row.original.id}
							object_type={'project'}
							initialValue={cell.row.original.tags}
						/>
					</>
				},
			},

		],
		[clients],
	);

	if (query.isLoading || clientsQuery.isLoading) {
		return 'Loading';
	}
	return (
		<>
			{addNewFormShown && <Paper sx={{p: 2, mb: 2}}>
				<FormNewProject client_id={client_id}/>
			</Paper>}


			<Table
				data={items}
				ToolbarActions={<PermissionsCheck role={'editor'} object_id={client_id} object_type={'client'}><Button
					variant="contained" size="small" startIcon={<AddCircleOutlineIcon/>}
					onClick={() => setAddNewFormShown(!addNewFormShown)}>New project</Button></PermissionsCheck>}
				deleteItems={deleteItems}
				columns={columns}
				tableInstanceRef={tableInstanceRef}
				enableRowOrdering={true}
				onDragEnd={(table) => {
					const {draggingRow, hoveredRow} = table.getState();
					if (hoveredRow && draggingRow) {
						items.splice(
							hoveredRow.index,
							0,
							items.splice(draggingRow.index, 1)[0],
						);
						apiFetch({
							path: `/wpify-erp/v1/project/order-index`,
							method: 'POST',
							data: {
								items
							}
						}).then((result) => {
							const queryKey = client_id ? ['projects', {client_id}] : ['projects'];
							queryClient.invalidateQueries({queryKey});

						})
					}
				}}
			/>

		</>

	);
}
export default Projects;
