import * as React from 'react';
import {useClients, useDocuments, useProjects, useTasks} from "../hooks";
import List from '@mui/material/List';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemIcon from '@mui/material/ListItemIcon';
import ListItemText from '@mui/material/ListItemText';
import Collapse from '@mui/material/Collapse';
import Badge from '@mui/material/Badge';
import ExpandLess from '@mui/icons-material/ExpandLess';
import ExpandMore from '@mui/icons-material/ExpandMore';
import BookmarkIcon from '@mui/icons-material/Bookmark';
import PersonIcon from '@mui/icons-material/Person';
import DescriptionIcon from '@mui/icons-material/Description';
import {useNavigate} from "react-router-dom";
import SupportTimeProgress from "./SupportTimeProgress";

export default function SidebarListMenu({active}) {
	const {deleteItems, items, query} = useClients();
	const navigate = useNavigate();

	const DocumentButtons = ({object_id, object_type}) => {
		const {items, query, deleteItems} = useDocuments({
			query_params: {
				object_id,
				object_type
			}
		});

		return items && items.map(item => <>
			<ListItemButton sx={{py:0}}
							onClick={() => navigate(`/document/${item.id}`)}
							selected={active && active.document === item.id}>
				<ListItemIcon sx={{minWidth: 28}}>
					<DescriptionIcon/>
				</ListItemIcon>
				<ListItemText primary={item.title} primaryTypographyProps={{fontSize: 14, noWrap: true}}/>
			</ListItemButton>
		</>)
	};

	const ProjectButtons = ({client_id}) => {
		const {items, query, deleteItems} = useProjects({
			client_id,
		});

		return items && items.map(item => <>
			<ListItemButton sx={{py: 0}}
							onClick={() => navigate(`/project/${item.id}`)}
							selected={active && active.project === item.id}>
				<ListItemIcon sx={{minWidth: 28}}>
					<BookmarkIcon/>
				</ListItemIcon>
				<ListItemText primary={item.name} primaryTypographyProps={{fontSize: 14, noWrap: true}}/>
			</ListItemButton>
			<DocumentButtons object_id={item.id} object_type={'project'}/>
		</>)
	};

	const ClientButton = ({item}) => {
		const [open, setOpen] = React.useState(active && active.client === item.id);
		const handleClick = () => {
			setOpen(!open);
		};

		return <>
			<ListItemButton sx={{py: '3px'}} selected={active && active.client === item.id}>
				<ListItemIcon sx={{minWidth: 36, position: 'relative'}} onClick={() => navigate(`/client/${item.id}`)}>
					<PersonIcon/>
					{item.support && (<SupportTimeProgress client_id={item.id} support={item.support}/>)}
				</ListItemIcon>
				<ListItemText
					onClick={() => navigate(`/client/${item.id}`)}
					primary={item.title}
					primaryTypographyProps={{fontSize: 14}}
					secondary={item.description}
					secondaryTypographyProps={{
						noWrap: true,
						fontSize: 12,
						lineHeight: '16px',
					}}
				/>
				{open ? <ExpandLess onClick={handleClick}/> : <ExpandMore onClick={handleClick}/>}
			</ListItemButton>
			<Collapse in={open} timeout="auto" unmountOnExit>
				<List component="div" disablePadding sx={{mb: 1, ml: 3, borderLeft: 1, borderColor: 'grey.300'}}>
					<DocumentButtons object_id={item.id} object_type={'client'}/>
					<ProjectButtons client_id={item.id}/>
				</List>
			</Collapse>
		</>
	}
	const ClientButtons = () => {
		return items && items.map(item => <ClientButton item={item}/>)
	};

	return (
		<List
			sx={{
				width: '100%',
				maxWidth: 240,
				height: '100%',
				maxHeight: 'calc(100vh - 70px)',
				overflow: 'auto',
				bgcolor: 'background.paper'
			}}
			component="nav"
			aria-labelledby="nested-list"
		>
			<ClientButtons/>
		</List>
	);
}
