import {MaterialReactTable} from "material-react-table";
import React, {useState} from "react";
import {ExportToCsv} from "export-to-csv";
import {IconButton} from '@mui/material';
import FileUploadIcon from '@mui/icons-material/FileUpload';
import IosShareIcon from '@mui/icons-material/IosShare';
import DeleteIcon from '@mui/icons-material/Delete';
import Tooltip from '@mui/material/Tooltip';
import Grid from '@mui/material/Grid';
import XLSX from "xlsx";

const Table = ({
				   data,
				   ToolbarActions = null,
				   deleteItems,
				   columns,
				   tableInstanceRef,
				   enableEditing = false,
				   onEditingRowSave,
				   onDragEnd,
				   enableRowOrdering = false,
				   filterFns = {}
			   }) => {
	const [rowSelection, setRowSelection] = useState({});
	const csvOptions = {
		fieldSeparator: ',',
		quoteStrings: '"',
		decimalSeparator: '.',
		showLabels: true,
		useBom: true,
		useKeysAsHeaders: false,
		headers: columns.map((c) => c.header),
	};

	const csvExporter = new ExportToCsv(csvOptions);
	const exportCsv = (items) => {
		const data = items.map((item) => {
			return columns.map((column) => {
				if (column.hasOwnProperty('accessorFn')) {
					return column.accessorFn(item, column, true);
				}

				return item[column.accessorKey];
			});
		});

		const worksheet = XLSX.utils.json_to_sheet(data);
		const workbook = XLSX.utils.book_new();
		XLSX.utils.book_append_sheet(workbook, worksheet, "export");
		XLSX.writeFile(workbook, "export.xlsx", { compression: true });
	}
	const handleExportData = () => {

		exportCsv(data);
	};

	const handleExportRows = (rows) => {
		exportCsv(rows.map((row) => row.original));
	};
	return (
		<>
			<MaterialReactTable
				muiTablePaginationProps={{
					rowsPerPageOptions: [5, 10, 50, 10, 10000000000],
					showFirstButton: false,
					showLastButton: false,
				}}
				columns={columns}
				data={data}
				enableRowSelection //enable some features
				enableColumnOrdering
				renderTopToolbarCustomActions={({table}) => {
					const rowSelection = tableInstanceRef.current.getState().rowSelection;
					return <Grid container spacing={2}>
						<Grid item xs>
							{ ToolbarActions }
						</Grid>
						<Grid item xs="auto">
							{Object.keys(rowSelection).length !== 0 &&
							<Tooltip title="Delete">
								<IconButton onClick={row => {
									const rowSelection = tableInstanceRef.current.getState().rowSelection;
									const ids = Object.keys(rowSelection);
									deleteItems({ids});
									setRowSelection({});

								}}><DeleteIcon/>
								</IconButton>
							</Tooltip>}
							<Tooltip title="Export">
								<IconButton onClick={handleExportData}><FileUploadIcon/></IconButton>
							</Tooltip>
							<Tooltip title="Export filtered">
								<IconButton onClick={() => handleExportRows(table.getRowModel().rows)}>
									<IosShareIcon/>
								</IconButton>
							</Tooltip>
						</Grid>
					</Grid>
				}}
				initialState={
					{
						pagination: {
							pageSize: 10000000000
						},
						density: 'compact'
					}
				}
				getRowId={(originalRow) => originalRow.id}
				tableInstanceRef={tableInstanceRef}
				onRowSelectionChange={setRowSelection} //connect internal row selection state to your own
				state={{rowSelection}} //pass our managed row selection state to the table to use
				enableEditing={enableEditing}
				editingMode="row"
				onEditingRowSave={onEditingRowSave}
				enableRowOrdering={enableRowOrdering}
				muiTableBodyRowDragHandleProps={({table}) => ({
					onDragEnd: () => onDragEnd ? onDragEnd(table) : null
				})}
				filterFns={{
					tagsFilterFn: (row, id, filterValue) => {
						const strings = row.original.tags.map(tag => tag.title).join(',').toLowerCase();
						console.log(strings);
						return strings.includes(filterValue.toLowerCase());
					},
					rawFilterFn: (row, id, filterValue) => {
						const string = tableInstanceRef.current.getColumn(id).accessorFn(row.original, id, true).toLowerCase();
						console.log(string.includes(filterValue.toLowerCase()), filterValue.toLowerCase(), string);
						return string.includes(filterValue.toLowerCase());
					},
				}}
				enableColumnFilterModes
			/>
		</>

	);
}
export default Table;
