import React, {useState, useEffect} from 'react';
import Tabs from '@mui/material/Tabs';
import Tab from '@mui/material/Tab';
import Box from '@mui/material/Box';
import {useUrlParams} from "../hooks";


const ReusableTabs = ({children}) => {
	const [activeTab, setActiveTab] = useState(0);
	const {splat, decodedSplat, params, addSplatToUrl} = useUrlParams();

	const handleChange = (event, newValue) => {
		handleSetActiveTab(newValue);
	};

	const tabList = [];
	const tabPanels = [];

	useEffect(() => {
		if (decodedSplat?.tab) {
			React.Children.forEach(children, (child, index) => {
				if (child.type === TabList) {
					React.Children.forEach(child.props.children, (tab, tabIndex) => {
						if (tab.props.id === decodedSplat.tab) {
							setActiveTab(tabIndex);
						}
					});
				}
			});

		}
	}, [decodedSplat, tabList]);

	const handleSetActiveTab = (newIndex) => {
		React.Children.forEach(children, (child, index) => {
			if (child.type === TabList) {
				React.Children.forEach(child.props.children, (tab, tabIndex) => {
					if (tabIndex === newIndex && tab.props.id) {
						const newSplat = {tab: tab.props.id};
						addSplatToUrl(newSplat);
					}
				});
			}
		});

		setActiveTab(newIndex);

	}


	React.Children.forEach(children, (child, index) => {
		if (child.type === TabList) {
			React.Children.forEach(child.props.children, (tab, tabIndex) => {
				tabList.push(
					<Tab
						key={`${tab.props.id ? tab.props.id : `tab-${index}`}`}
						label={tab.props.children}
						className="inline"
						onClick={(event) => handleChange(event, tabIndex)}
					/>
				);
			});
		} else if (child.type === TabPanel) {
			tabPanels.push(
				<TabPanel key={`tabpanel-${index}`} value={activeTab} index={tabPanels.length}>
					{child.props.children}
				</TabPanel>
			);
		}
	});

	return (
		<Box>
			<Box sx={{borderBottom: 1, borderColor: 'divider'}}>
				<Tabs value={activeTab} onChange={handleChange}>
					{tabList}
				</Tabs>
			</Box>
			{tabPanels}
		</Box>
	);
};

const TabList = ({children}) => {
	return <div>{children}</div>;
};

const TabPanel = ({children, value, index}) => {
	return (
		<div className="my-4" role="tabpanel" hidden={value !== index}>
			{value === index && (
				<Box>
					{children}
				</Box>
			)}
		</div>
	);
};

export {ReusableTabs, TabList, TabPanel};
