import CreatableSelect from 'react-select/creatable';
import React, {useState, useEffect} from "react";
import {useCurrentUserData, useTags} from "../hooks";
import {useQueryClient} from "@tanstack/react-query";
import apiFetch from "@wordpress/api-fetch";
import ColorPicker from "./Form/ColorPicker";
import Button from '@mui/material/Button';
import InputTextControlled from "./Form/InputTextControlled";
import {default as ReactSelect, StylesConfig} from "react-select";
import Row from "./Row";
import Column from "./Column";
import Card from "./Card";
import chroma from 'chroma-js';
import PermissionsCheck from "./PermissionsCheck";

const colourStyles = {
	control: styles => ({...styles, backgroundColor: "white"}),
	option: (styles, {data, isDisabled, isFocused, isSelected}) => {
		const color = chroma(data.color)
		return {
			...styles,
			backgroundColor: isDisabled
				? undefined
				: isSelected
					? data.color
					: isFocused
						? color.alpha(0.6).css()
						: undefined,
			color: isDisabled
				? "#ccc"
				: isSelected
					? chroma.contrast(color, "white") > 2
						? "white"
						: "black"
					: data.color,
			cursor: isDisabled ? "not-allowed" : "default",

			":active": {
				...styles[":active"],
				backgroundColor: !isDisabled
					? isSelected
						? data.color
						: color.alpha(0.3).css()
					: undefined
			}
		}
	},
	multiValue: (styles, {data}) => {
		const color = chroma(data.color)
		return {
			...styles,
			backgroundColor: color.alpha(0.5).css()
		}
	},
	multiValueLabel: (styles, {data}) => ({
		...styles,
		color: data.color
	}),
	multiValueRemove: (styles, {data}) => ({
		...styles,
		color: data.color,
		":hover": {
			backgroundColor: data.color,
			color: "white"
		}
	})
}

const createOption = (label) => ({
	label,
	value: label.toLowerCase().replace(/\W/g, ''),
});

export const addMultipleTags = (object_id, object_type, value) => apiFetch({
	path: `/wpify-erp/v1/tag-relationship/add-multiple`,
	method: 'POST',
	data: {
		object_id: object_id,
		object_type: object_type,
		items: value
	}
}).then((result) => {
	console.log(result);
});
const TagSelect = ({object_id, object_type, initialValue, onChangeCustom}) => {
	const {items: tags, query, createAsync} = useTags()
	const [isLoading, setIsLoading] = useState(false);
	const [value, setValue] = useState();
	const [options, setOptions] = useState([]);
	const [addNewShown, setAddNewShown] = useState(false);
	const [newTitle, setNewTitle] = useState('');
	const [newColor, setNewColor] = useState(null);
	const {userCan} = useCurrentUserData();
	const onChange = (value) => {
		setValue(value);
		if (!onChangeCustom) {
			addMultipleTags(object_id, object_type, value);
		} else {
			onChangeCustom(value)
		}
	}

	useEffect(() => {
		if (initialValue && options) {
			const options = initialValue.map(tag => ({value: tag.id, label: tag.title, color: tag.color}))
			setValue(options)
		}
	}, [initialValue, options]);

	useEffect(() => {
		if (tags) {
			const options = tags.map(tag => ({value: tag.id, label: tag.title, color: tag.color}))
			setOptions(options)
		}
	}, [tags]);
	const queryClient = useQueryClient();
	const handleCreate = () => {
		setIsLoading(true);
		createAsync({title: newTitle, color: newColor ? newColor : null}).then((result) => {
			setIsLoading(false);
			queryClient.invalidateQueries({
				queryKey: ['tags']
			}).then(() => {
				let newValue = {label: result.item.title, value: result.item.id, color: result.item.color};
				if (value) {
					newValue = [...value, newValue];
				} else {
					newValue = [newValue];
				}
				setValue(newValue);
				onChange(newValue)
				setAddNewShown(false)
			})
		})
	};
	const onSubmit = (data) => {

	}
	if (query.isLoading) {
		return 'Loading'
	}


	return <>
		<label className="mt-2">Tags
			<PermissionsCheck object_id={object_id} object_type={object_type} role={'editor'}>
				<Button type="button" size="small" onClick={() => setAddNewShown(!addNewShown)}>Add</Button>
			</PermissionsCheck></label>
		{addNewShown ? <div className="mt-2">
			<Card>
				<Row>
					<Column>
						<InputTextControlled
							label={'Title'}
							name={'title'}
							onChange={() => setNewTitle(event.target.value)}
							placeholder={'Title'}
						/>
					</Column>
					<Column>
						<label className="block text-gray-700 text-sm font-bold mb-2" htmlFor="title">Color</label>
						<ColorPicker
							onChange={(color) => setNewColor(color)}
						/>
					</Column>
					<Column>
						<Button type="button" onClick={() => handleCreate()} variant="outlined">Save</Button>
					</Column>
				</Row>
			</Card>
		</div> : <ReactSelect
			onChange={onChange}
			value={value}
			isDisabled={isLoading || (object_type && object_id && !userCan('editor', object_type, object_id))}
			isLoading={isLoading}
			isClearable={true}
			options={options}
			menuPortalTarget={document.body}
			isMulti
			styles={{...colourStyles, menuPortal: base => ({...base, zIndex: 9999})}}
		/>}

	</>
}
export default TagSelect;
