import {useState, useEffect, useRef} from "react"
import {useSortable} from "@dnd-kit/sortable"
import {CSS} from "@dnd-kit/utilities"
import {useNavigate} from "react-router-dom";
import Button from "./Form/Button";

function TaskCard({task, deleteTask, updateTask}) {
	const navigate = useNavigate();

	const [mouseIsOver, setMouseIsOver] = useState(false)
	const [editMode, setEditMode] = useState(true)
	const timer = useRef(null)
	const [editedText, setEditedText] = useState(task.content);

	useEffect(() => {
		clearTimeout(timer.current)
		timer.current = setTimeout(() => {
			if (editedText !== task.content) {
				updateTask(task.id, editedText);
			}

		}, 1000)

	}, [editedText])

	const {
		setNodeRef,
		attributes,
		listeners,
		transform,
		transition,
		isDragging
	} = useSortable({
		id: task.id,
		data: {
			type: "Task",
			task
		},
		disabled: editMode
	})

	const style = {
		transition,
		transform: CSS.Transform.toString(transform)
	}

	const toggleEditMode = () => {
		setEditMode(prev => !prev)
		setMouseIsOver(false)
	}

	if (isDragging) {
		return (
			<div
				ref={setNodeRef}
				style={style}
				className="
        opacity-30
      bg-gray-100 p-2.5 h-[100px] min-h-[100px] items-center flex text-left rounded-xl border-2 border-rose-500  cursor-grab relative
      "
			/>
		)
	}

	if (editMode) {
		return (
			<div
				ref={setNodeRef}
				style={style}
				{...attributes}
				{...listeners}
				className="bg-gray-100 p-2.5 h-[100px] min-h-[100px] items-center flex text-left rounded-xl hover:ring-2 hover:ring-inset hover:ring-rose-500 cursor-grab relative"
			>
        <textarea
			className="

        w-full resize-none border-none rounded bg-transparent text-black focus:outline-none
        "
			value={editedText}
			autoFocus
			placeholder="Task content here"
			onBlur={toggleEditMode}
			onKeyDown={e => {
				if (e.key === "Enter" && e.shiftKey) {
					toggleEditMode()
				}
			}}
			onChange={e => setEditedText(e.target.value)}
		/>
			</div>
		)
	}

	return (
		<div
			ref={setNodeRef}
			style={style}
			{...attributes}
			{...listeners}
			className="bg-white bg-clip-border shadow-3xl shadow-shadow-500 p-2.5 h-[100px] min-h-[100px] items-center flex text-left rounded-xl hover:ring-2 hover:ring-inset hover:ring-rose-500 cursor-grab relative task"
			onMouseEnter={() => {
				setMouseIsOver(true)
			}}
			onMouseLeave={() => {
				setMouseIsOver(false)
			}}
		>
			<p className="my-auto w-full overflow-y-auto overflow-x-hidden whitespace-pre-wrap"
			   onClick={toggleEditMode}>
				{editedText}
			</p>

			{mouseIsOver && (
				<div className="flex">
					<Button className="mr-2" onClick={() => navigate(`/task/${task.id}`)} label="Detail"/>
					<Button onClick={() => deleteTask(task.id)} label="Smazat"/>
				</div>

			)}
		</div>
	)
}

export default TaskCard
