import React, {useEffect, useState} from "react";
import {useForm} from "react-hook-form"
import {Routes, Route, useParams, useNavigate, useOutletContext} from 'react-router-dom';
import {
	useCurrentUserData,
	useTask,
	useTaskStatuses,
	useUsers
} from "../hooks";
import FormTaskComment from "./FormTaskComment";
import Comment from "./Comment";
import Select from 'react-select'
import InputLabel from '@mui/material/InputLabel';
import FormControl from '@mui/material/FormControl';
import FormTimeEntry from "./FormTimeEntry";
import EditableText from "./EditableText";
import Tab from '@mui/material/Tab';
import Typography from '@mui/material/Typography';
import TagSelect from "./TagSelect";
import {toHoursAndMinutes} from "./TimeEntries";
import {ReusableTabs, TabPanel, TabList} from "./Tabs";
import PermissionsCheck from "./PermissionsCheck";
import SwitchControlled from "./Form/SwitchControlled";
import Chip from '@mui/material/Chip';
import DatepickerControlled from "./Form/DatepickerControlled";
import {format} from 'date-fns'
import Badge from '@mui/material/Badge';
import Grid from '@mui/material/Grid';
import Stack from '@mui/material/Stack';
import Paper from '@mui/material/Paper';
import Box from '@mui/material/Box';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import AssignmentTurnedInIcon from '@mui/icons-material/AssignmentTurnedIn';
import AccessTimeIcon from "@mui/icons-material/AccessTime";
import ProgressCircles from "./ProgressCircles";
import Checklist from "./Checklist";

const TaskDetail = (props) => {

	let {task_id} = useParams();
	if (task_id) {
		task_id = parseInt(task_id);
	}

	const navigate = useNavigate();
	const {
		register,
		handleSubmit,
		watch,
		formState: {errors},
	} = useForm()

	const {isInternal, isAdmin, query} = useCurrentUserData();
	const {item, query: taskQuery, mutate} = useTask({id: task_id});
	const {items: users, query: usersQuery} = useUsers();
	const {items: taskStatuses, query: taskStatusesQuery} = useTaskStatuses();

	const [timeTrackingFormShown, setTimeTrackingFormShown] = useState(false);

	const usersSelect = users ? users.map(item => ({
		label: item.display_name,
		value: item.id
	})) : [];

	const taskStatusesSelect = taskStatuses ? taskStatuses : [];

	const toggleTrackingTimeFormShown = () => {
		setTimeTrackingFormShown(!timeTrackingFormShown);
	}
	const totalTime = () => {
		let total = 0;
		item.time_entries.forEach(entry => {
			total += entry.minutes;
		})

		return total;
		// const time = toHoursAndMinutes(total);
		// return `${time.hours}h ${parseInt(time.minutes) !== 0 ? time.minutes + 'm' : ''}`;
	}
	const totalTimeFormatted = () => {
		const time = toHoursAndMinutes(totalTime());
		return `${time.hours}h ${parseInt(time.minutes) !== 0 ? time.minutes + 'm' : ''}`;
	}

	const {setHeader, setBreadcrumbsRoute, setActiveMenuItem} = useOutletContext();
	useEffect(() => {
		if (item) {
			setHeader(() => () => <>{item.title}</>);
			setBreadcrumbsRoute([
				{'label': 'Clients', 'link': '/client'},
				{'label': `${item.client.title}`, 'link': `/client/${item.client.id}`},
				{'label': `${item.project.name}`, 'link': `/project/${item.project.id}`},
				{'label': `${item.title}`}
			]);
			setActiveMenuItem({client: item.client.id, project: item.project.id});
		}

	}, [item]);

	return (
		<>
			{taskQuery.isLoading || usersQuery.isLoading || taskStatusesQuery.isLoading ? 'Loading' : <>
				{/*<Stack*/}
				{/*	direction="row"*/}
				{/*	spacing={2}*/}
				{/*>*/}
				{/*	{item.client &&*/}
				{/*	<Chip label={item.client.title} onClick={() => navigate(`/client/${item.client.id}`)}/>}*/}
				{/*	{item.project &&*/}
				{/*	<Chip label={item.project.name}*/}
				{/*		  onClick={() => navigate(`/project/${item.project.id}`)}/>}*/}
				{/*</Stack>*/}
				<Paper sx={{p: 2, mb: 2}}>
					<Grid container spacing={3}>
						<Grid item xs="auto">
							<AssignmentTurnedInIcon color="action" sx={{fontSize: 46}}/>
							<Box sx={{mt: 3, position: 'relative'}}>
								<AccessTimeIcon color="primary" sx={{mx: 1, mb: 1}}/>
								<ProgressCircles current={totalTime() / 60}/>
								<Box sx={{displayPrint: 'block'}}>{totalTimeFormatted()}</Box>
							</Box>
						</Grid>
						<Grid item xs={8}>
							<h2>
								<PermissionsCheck role="editor" permissionRole={item.permission_role}
												  noPermissionContent={item.title} showErrorMessage={true}>
									<EditableText
										label={'Title'}
										text={item.title}
										onChange={value => mutate({title: value})}
									/>
								</PermissionsCheck>

							</h2>
							<PermissionsCheck role="editor" permissionRole={item.permission_role}
											  noPermissionContent={item.description.replace(/(?:\r\n|\r|\n)/g, '<br>')}
											  showErrorMessage={true}>
								<EditableText
									label={'Description'}
									text={item.description.replace(/(?:\r\n|\r|\n)/g, '<br>')}
									onChange={value => mutate({description: value})}
								/>
							</PermissionsCheck>
							<Checklist checklist={item.checklist} mutate={mutate}/>
						</Grid>
						<Grid item xs>
							<Stack
								direction="column"
								spacing={2}
							>
								<Stack
									direction="row"
									spacing={3}
								>
									<Box>
										<h3 className="mt-1">Assigned user</h3>
										<PermissionsCheck role="editor" permissionRole={item.permission_role}
														  noPermissionContent={usersSelect.find(option => item.assigned_user_id === option.value)?.value}>
											<Select
												options={usersSelect}
												value={usersSelect.find(option => item.assigned_user_id === option.value)}
												onChange={option => {
													mutate({assigned_user_id: option.value})
												}}
											/>

										</PermissionsCheck>
									</Box>
									<Box>
										<h3 className="mt-1">Status</h3>
										<PermissionsCheck role="editor" permissionRole={item.permission_role}
														  noPermissionContent={taskStatusesSelect.find(option => item.status === option.value)?.value}>
											<Select
												options={taskStatusesSelect}
												value={taskStatusesSelect.find(option => item.status === option.value)}
												onChange={option => {
													mutate({status: option.value})
												}}

											/>
										</PermissionsCheck>
									</Box>
								</Stack>
								<PermissionsCheck role="editor" permissionRole={item.permission_role}
												  noPermissionContent={item.due_date}>
									<DatepickerControlled
										label="Due date"
										placeholder={"Due date"}
										onChange={value => {
											mutate({due_date: value ? format(value, 'yyyy-MM-dd HH:mm:ss') : ''})
										}}
										defaultValue={item.due_date ? new Date(item.due_date) : null}
									/>
								</PermissionsCheck>
								<Box>
									<TagSelect
										object_id={task_id}
										object_type={'task'}
										initialValue={item.tags}
									/>
								</Box>
								<Box>
									<Stack
										direction="row"
										spacing={3}
									>
										{(isInternal || isAdmin) &&
										<SwitchControlled
											onChange={value => mutate({internal: value ? 1 : 0})}
											label={'Internal'}
											defaultValue={item.internal}
										/>
										}
										<SwitchControlled
											onChange={value => mutate({private: value ? 1 : 0})}
											label={'Private'}
											defaultValue={item.private}
										/>
									</Stack>
								</Box>
							</Stack>
						</Grid>
					</Grid>

				</Paper>

				<ReusableTabs>
					<TabList>
						<Tab id="comments">
							<Badge badgeContent={item.comments.length} color="primary" sx={{pr: 2}} showZero>
								Comments
							</Badge>
						</Tab>
						<Tab id="time-tracking">
							<Badge badgeContent={item.time_entries.length} color="primary" sx={{pr: 2}} showZero>
								Time Tracking
							</Badge>
						</Tab>
						<Tab id="attachments">
							<Badge badgeContent={item.attachments.length} color="primary" sx={{pr: 2}} showZero>
								Attachments
							</Badge>
						</Tab>
					</TabList>

					<TabPanel>
						{item.comments.map(item => <Comment
							comment={item}/>)}
						<FormTaskComment/>
					</TabPanel>
					<TabPanel>
						<h2>Total tracked time:
							<Chip label={totalTimeFormatted()} color="primary"/>
						</h2>
						<FormTimeEntry
							task_id={task_id}
							project_id={item.project_id}
							client_id={item.client_id}
						/>

						<TableContainer component={Paper}>
							<Table sx={{minWidth: 650}} size="small" aria-label="a tracked time table">
								<TableHead>
									<TableRow>
										<TableCell>Time</TableCell>
										<TableCell>Date</TableCell>
										<TableCell>Description</TableCell>
										<TableCell>Internal</TableCell>
										<TableCell>Private</TableCell>
									</TableRow>
								</TableHead>
								<TableBody>
									{item.time_entries.map(entry => {
										const time = toHoursAndMinutes(entry.minutes);
										return <TableRow
											key={entry.id}
											sx={{'&:last-child td, &:last-child th': {border: 0}}}
										>
											<TableCell component="th" scope="row">
												{`${time.hours}h ${parseInt(time.minutes) !== 0 ? time.minutes + 'm' : ''}`}
											</TableCell>
											<TableCell>{entry.date_start}</TableCell>
											<TableCell>{entry.description}</TableCell>
											<TableCell>{entry.internal ? 'Yes' : 'No'}</TableCell>
											<TableCell>{entry.private ? 'Yes' : 'No'}</TableCell>
										</TableRow>
									})}
								</TableBody>
							</Table>
						</TableContainer>
					</TabPanel>
					<TabPanel>
						<h3>Attachments</h3>
						<div className="flex">
							{item.attachments.map(attachment => <>
								{attachment.type.includes('image') ? <>
									<a className="w-1/4 inline-block mr-2" href={attachment.url}
									   target="_blank"><img
										src={attachment.url} alt=""/></a>

								</> : <a href={attachment.url} target="_blank">{attachment.path}</a>}

							</>)}
						</div>
					</TabPanel>
				</ReusableTabs>
			</>}
		</>
	)
}
export default TaskDetail;
