import React, {useState, useEffect} from 'react';
import {format, intervalToDuration} from 'date-fns';
import Button from '@mui/material/Button';
import {useClients, useProjects, useTasks} from "../hooks";

const TrackTime = ({
					   onStopTracking,
					   client_id,
					   project_id,
					   task_id,
					   options_client,
					   options_tasks,
					   options_project
				   }) => {
	const setTracker = () => {
		const data = {
			'start': format(new Date(), 'yyyy-MM-dd HH:mm:ss'),
			client_id,
			project_id,
			task_id
		};
		localStorage.setItem('tracker', JSON.stringify(data));
		setIsRunning(true);
	}
	const clearTracker = () => {
		localStorage.removeItem('tracker');
	}
	const getTracker = () => {
		const tracker = localStorage.getItem('tracker');
		if (tracker) {
			const data = JSON.parse(tracker);
			return data;
		}
		return null;
	}

	const getTime = () => {
		let time = null;
		const data = getTracker();
		if (data) {
			time = intervalToDuration({
				start: new Date(data.start),
				end: new Date()
			})
		}
		return time;
	}

	const [isRunning, setIsRunning] = useState(getTracker);
	const [duration, setDuration] = useState(getTime());


	useEffect(() => {
		const interval = setInterval(() => setDuration(getTime()));
		return () => {
			clearInterval(interval);
		};
	}, [getTime]);

	const handleStopTracking = () => {
		setIsRunning(false);
		const original_minutes = duration.minutes;

		duration.minutes = 15;
		if (original_minutes > 15) {
			duration.minutes = 30;
		}
		if (original_minutes > 30) {
			duration.minutes = 45;
		}
		if (original_minutes > 45) {
			duration.minutes = 0;
			duration.hours = duration.hours + 1;
		}

		onStopTracking(duration, getTracker())
		clearTracker();
	}

	const handleStartTracking = () => {
		setTracker();
	}

	const data = getTracker();

	return <>
		{
			isRunning ? <>
				{duration && <>
					<span className="text-xl mr-4 bg-red-300 text-white p-3 rounded">{duration.hours} : {(duration.minutes).toLocaleString('en-US', {minimumIntegerDigits: 2, useGrouping:false})} : {(duration.seconds).toLocaleString('en-US', {minimumIntegerDigits: 2, useGrouping:false})}</span>
					{data.client_id && <span
						className="bg-blue-100 text-blue-800 font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">{options_client.find(item => item.value === data.client_id).label}</span>}
					{data.project_id && <span
						className="bg-blue-100 text-blue-800 font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">{options_project.find(item => item.value === data.project_id).label}</span>}
					{data.task_id &&
						<span className="bg-blue-100 text-blue-800 font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">{options_tasks.find(item => item.value === data.task_id).label}</span>}
				</>
				}
				<Button onClick={() => handleStopTracking()} variant="outlined">Stop time</Button>
			</> : <>
				<Button onClick={() => handleStartTracking()} variant="outlined">Start time</Button>
			</>
		}

	</>
}
export default TrackTime;
