<?php

namespace WpifyErp\Abstracts;

use WpifyErp\Models\PermissionModel;
use WpifyErpDeps\Wpify\Model\CustomTableRepository;
use WpifyErpDeps\Wpify\Model\Interfaces\ModelInterface;

abstract class AbstractRepository extends CustomTableRepository {
	public function soft_delete( ModelInterface $model ) {
		$this->auto_migrate();
		if ( empty( $this->primary_key( $model ) ) ) {
			return \false;
		}

		$result = $this->db()->update(
			$this->prefixed_table_name(),
			array(
				'deleted_at' => date( 'Y-m-d H:i:s' ),
			),
			array(
				$this->primary_key() => $this->primary_key( $model ),
			)
		);

		return $this->db()->update(
			$this->prefixed_table_name(),
			array(
				'deleted_at' => date( 'Y-m-d H:i:s' ),
			),
			array(
				$this->primary_key() => $this->primary_key( $model ),
			)
		);

		return $result;
	}

	public function find( array $args = array() ): array {
		$defaults = array(
			'where' => array(),
		);

		$args = wp_parse_args( $args, $defaults );
		if ( is_string( $args['where'] ) ) {
			$args['where'] = array( $args['where'] );
		}
		$args['where'][] = [
			'deleted_at' => null,
		];

		// Skip permissions for new records.
		$args = $this->apply_default_permissions( $args );

		if ( ! current_user_can( 'administrator' ) ) {
			$args = $this->apply_permissions( $args );
		}

//		if ( property_exists( $this->model(), 'private' ) ) {
//			$args['where'] = [
//				$args['where'],
//				'or',
//				[
//					'private' => 1,
//					'user_id' => get_current_user_id(),
//				],
//			];
//		}

		return parent::find( $args );
	}

	public function apply_permissions( array $args ) {
		return $args;
	}

	public function get_user_permissions( int $user_id = 0 ) {
		return $this->manager()->get_model_repository( PermissionModel::class )->get_user_permissions();
	}

	public function apply_default_permissions( $args ) {
		if (property_exists( $this->model(), 'order_index' )) {
			$args['order_by'] = 'order_index';
		}
		if ( ! current_user_can( 'administrator' ) ) {
			if ( ! current_user_can( 'wpify_erp_internal' ) && property_exists( $this->model(), 'internal' ) ) {
				$args['where'][] = [
					"internal <>" => 1,
				];
			}
		}

		return $args;
	}
}
