<?php

namespace WpifyErp\Api;

use WP_REST_Controller;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WpifyErp\Abstracts\AbstractRest;
use WpifyErp\Controllers\ProjectController;
use WpifyErp\Controllers\TaskController;
use WpifyErp\Controllers\UserController;
use WpifyErp\Enums\Modules;
use WpifyErp\Enums\Roles;
use WpifyErp\Enums\TaskStatuses;
use WpifyErp\Managers\ApiManager;
use WpifyErp\Repositories\ProjectRepository;
use WpifyErp\Repositories\TaskRepository;
use WpifyErp\Repositories\UserRepository;

class EnumApi extends AbstractRest {
	public function __construct(
		private UserController $user_controller,
		private UserRepository $user_repository
	) {
		add_action( 'rest_api_init', [ $this, 'register_routes' ] );
	}

	/**
	 * Register the routes for the objects of the controller.
	 */
	public function register_routes() {
		register_rest_route(
			ApiManager::ENDPOINT,
			'enum/task-status',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'get_task_statuses' ),
					'permission_callback' => [ $this, 'get_items_permissions_check' ],
				),
			)
		);
		register_rest_route(
			ApiManager::ENDPOINT,
			'enum',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'get_enums' ),
					'permission_callback' => [ $this, 'get_items_permissions_check' ],
				),
			)
		);
	}

	/**
	 * Add box to cart
	 *
	 * @param  WP_REST_Request  $request  Full data about the request.
	 *
	 * @return WP_REST_Response
	 */
	public function get_task_statuses( $request ) {
		return new WP_REST_Response( [ 'items' => TaskStatuses::get_items() ], 200 );
	}

	/**
	 * Add box to cart
	 *
	 * @param  WP_REST_Request  $request  Full data about the request.
	 *
	 * @return WP_REST_Response
	 */
	public function get_enums( $request ) {
		$enums = [
			'task_statuses' => TaskStatuses::get_items(),
			'roles'         => Roles::get_items(),
			'modules'       => Modules::get_items(),
		];

		return new WP_REST_Response( [ 'items' => $enums ], 200 );
	}

	public function get_items( $request ) {
		$items = $this->user_controller->get_items();


		return new WP_REST_Response( [ 'items' => $items ] );
	}

	public function base(): string {
		return 'enum';
	}
}
