<?php

namespace WpifyErp\Api;

use WP_REST_Controller;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WpifyErp\Abstracts\AbstractRest;
use WpifyErp\Controllers\ActivityLogController;
use WpifyErp\Controllers\ClientController;
use WpifyErp\Controllers\DocumentController;
use WpifyErp\Controllers\PermissionController;
use WpifyErp\Controllers\ProjectController;
use WpifyErp\Controllers\TaskController;
use WpifyErp\Enums\TaskStatuses;
use WpifyErp\Managers\ApiManager;
use WpifyErp\Models\PermissionModel;
use WpifyErp\Repositories\ActivityLogRepository;
use WpifyErp\Repositories\AttachmentRepository;
use WpifyErp\Repositories\ClientRepository;
use WpifyErp\Repositories\DocumentRepository;
use WpifyErp\Repositories\PermissionRepository;
use WpifyErp\Repositories\ProjectRepository;
use WpifyErp\Repositories\TaskCommentRepository;
use WpifyErp\Repositories\TaskRepository;
use WpifyErp\Repositories\TimeEntryRepository;

class PermissionApi extends AbstractRest {
	public function __construct(
		public PermissionController $controller,
		public PermissionRepository $repository,

	) {
		parent::__construct();
	}

	public function update_item( $request ) {
		/** @var PermissionModel $item */
		$item = $this->repository->get( $request->get_param( 'id' ) );
		foreach ( $request->get_params() as $key => $value ) {
			if ( $key === 'id' ) {
				continue;
			}
			if ( $key === 'modules' ) {
				$context = $item->context;
				foreach ( $value as $module_key => $module ) {
					if ( ! empty( $module['role'] ) || is_null( $module['role'] ) ) {
						$context['modules'][ $module_key ]['role'] = (string) $module['role'];
					}
				}
				$item->context = $context;
			} elseif ( isset( $item->{$key} ) ) {
				$item->{$key} = $value;
			}
		}

		$this->repository->save( $item );
		erp_add_log( 'update', $item['id'], str_replace( '-', '_', $this->base() ), $request->get_params() );

		return $this->get_item( $request );
	}

	public function base(): string {
		return 'permission';
	}
}
