<?php

namespace WpifyErp\Api;

use Ramsey\Uuid\Uuid;
use WP_REST_Controller;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WpifyErp\Abstracts\AbstractRest;
use WpifyErp\Controllers\ClientController;
use WpifyErp\Controllers\ProjectController;
use WpifyErp\Controllers\TaskController;
use WpifyErp\Enums\TaskStatuses;
use WpifyErp\Managers\ApiManager;
use WpifyErp\Models\TaskModel;
use WpifyErp\Repositories\AttachmentRepository;
use WpifyErp\Repositories\ClientRepository;
use WpifyErp\Repositories\ProjectRepository;
use WpifyErp\Repositories\TaskCommentRepository;
use WpifyErp\Repositories\TaskRepository;
use WpifyErp\Repositories\TimeEntryRepository;

class SearchApi extends WP_REST_Controller {
	public function __construct(
		private TaskController $task_controller,
		private TaskRepository $task_repository,
		private ClientRepository $client_repository,
		private ClientController $client_controller,
		private ProjectRepository $project_repository,
		private ProjectController $project_controller,
	) {
		add_action( 'rest_api_init', [ $this, 'register_custom_routes' ] );
	}

	/**
	 * Register the routes for the objects of the controller.
	 */
	public function register_custom_routes() {
		register_rest_route(
			ApiManager::ENDPOINT,
			'search',
			array(
				array(
					'methods'             => WP_REST_Server::CREATABLE,
					'callback'            => array( $this, 'search' ),
					'permission_callback' => 'is_user_logged_in',
				),
			)
		);
	}

	/**
	 * Add box to cart
	 *
	 * @param  WP_REST_Request  $request  Full data about the request.
	 *
	 * @return WP_REST_Response
	 */
	public function search( $request ) {
		$query          = $request->get_param( 'query' );
		$client_where   = [
			'title LIKE'       => '%' . $query . '%',
			'OR',
			'description LIKE' => '%' . $query . '%',
		];
		$tasks_where    = [
			'title LIKE'       => '%' . $query . '%',
			'OR',
			'description LIKE' => '%' . $query . '%',
		];
		$projects_where = [
			'name LIKE'        => '%' . $query . '%',
			'OR',
			'description LIKE' => '%' . $query . '%',
		];

		$result = [
			'clients'  => $this->client_controller->get_items( [ 'where' => $client_where ] ),
			'projects' => $this->project_controller->get_items( [ 'where' => $projects_where ] ),
			'tasks'    => $this->task_controller->get_items( [ 'where' => $tasks_where ] ),
		];

		return new WP_REST_Response(  $result , 200 );
	}

}
