<?php

namespace WpifyErp\Api;

use WP_REST_Controller;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WpifyErp\Abstracts\AbstractRest;
use WpifyErp\Controllers\ActivityLogController;
use WpifyErp\Controllers\ClientController;
use WpifyErp\Controllers\DocumentController;
use WpifyErp\Controllers\ProjectController;
use WpifyErp\Controllers\TagController;
use WpifyErp\Controllers\TagRelationshipController;
use WpifyErp\Controllers\TaskController;
use WpifyErp\Enums\TaskStatuses;
use WpifyErp\Managers\ApiManager;
use WpifyErp\Repositories\ActivityLogRepository;
use WpifyErp\Repositories\AttachmentRepository;
use WpifyErp\Repositories\ClientRepository;
use WpifyErp\Repositories\DocumentRepository;
use WpifyErp\Repositories\ProjectRepository;
use WpifyErp\Repositories\TagRelationshipRepository;
use WpifyErp\Repositories\TagRepository;
use WpifyErp\Repositories\TaskCommentRepository;
use WpifyErp\Repositories\TaskRepository;
use WpifyErp\Repositories\TimeEntryRepository;

class TagRelationshipApi extends AbstractRest {
	public function __construct(
		public TagRelationshipController $controller,
		public TagRelationshipRepository $repository,

	) {
		parent::__construct();
		add_action( 'rest_api_init', [ $this, 'register_custom_routes' ] );
	}

	public function register_custom_routes() {
		register_rest_route(
			ApiManager::ENDPOINT,
			$this->base() . '/add-multiple',
			array(
				array(
					'methods'  => WP_REST_Server::CREATABLE,
					'callback' => array( $this, 'add_multiple' ),
					'args'     => array(),
					'permission_callback' => [ $this, 'create_item_permissions_check' ],
				),
			)
		);
	}

	public function add_multiple( WP_REST_Request $request ) {
		$current_where = sprintf( 'object_id = %s AND object_type = "%s"', $request->get_param( 'object_id' ), $request->get_param( 'object_type' ) );
		$tags          = $this->repository->find( [ 'where' => $current_where ] );
		$new_tags      = $request->get_param( 'items' );
		$new_tags_ids  = array_map( function ( $item ) {
			return $item['value'];
		}, $new_tags );
		foreach ( $tags as $tag ) {
			if ( ! in_array( $tag->id, $new_tags_ids ) ) {
				$this->repository->delete( $tag );
			}
		}
		// Save new tags
		foreach ( $request->get_param( 'items' ) as $item ) {
			$where = sprintf( 'object_id = %s AND object_type = %s and tag_id = %s', $request->get_param( 'object_id' ), $request->get_param( 'object_type' ), $item['value'] );

			$found = $this->repository->get( [ 'where' => $where ] );
			if ( $found ) {
				continue;
			}
			$new = $this->repository->create(
				[
					'object_id'   => $request->get_param( 'object_id' ),
					'object_type' => $request->get_param( 'object_type' ),
					'tag_id'      => $item['value'],
					'user_id' => get_current_user_id()
				]
			);
			$this->repository->save( $new );
		}

		return $this->get_items( $request );
	}

	public function base(): string {
		return 'tag-relationship';
	}
}
