<?php

namespace WpifyErp\Api;

use WP_REST_Controller;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WpifyErp\Abstracts\AbstractRest;
use WpifyErp\Controllers\ProjectController;
use WpifyErp\Controllers\TaskController;
use WpifyErp\Controllers\UserController;
use WpifyErp\Managers\ApiManager;
use WpifyErp\Repositories\ProjectRepository;
use WpifyErp\Repositories\TaskRepository;
use WpifyErp\Repositories\UserRepository;

class UserApi extends AbstractRest {
	public function __construct(
		public UserController $controller,
		public UserRepository $repository
	) {
		parent::__construct();
		add_action( 'rest_api_init', [ $this, 'register_custom_routes' ] );
	}

	public function register_custom_routes() {
		register_rest_route(
			ApiManager::ENDPOINT,
			$this->base() . '/current',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'get_current_user' ),
					'permission_callback' => [ $this, 'get_items_permissions_check' ],
				),
			)
		);
	}

	public function get_current_user() {
		$user = $this->controller->get_item( get_current_user_id() );

		return new WP_REST_Response( [ 'item' => $user ] );
	}

	public function base(): string {
		return 'user';
	}
}
