<?php

namespace WpifyErp\Blocks;

use WpifyErp\PostTypes\BookPostType;
use WpifyErp\Repositories\BookRepository;
use WpifyErpDeps\Wpify\CustomFields\CustomFields;
use WpifyErpDeps\Wpify\Template\WordPressTemplate;

class BookBlock {
	private $wcf;
	private $template;
	private $book_repository;

	public function __construct( CustomFields $wcf, WordPressTemplate $template, BookRepository $book_repository ) {
		$this->wcf             = $wcf;
		$this->template        = $template;
		$this->book_repository = $book_repository;

		$this->setup();
	}

	public function setup() {
		$this->wcf->create_gutenberg_block( array(
			'name'            => 'wpify-erp/book',
			'title'           => __( 'Book', 'wpify-erp' ),
			'render_callback' => array( $this, 'render' ),
			'items'           => array(
				array(
					'type'      => 'post',
					'id'        => 'book',
					'title'     => __( 'Book', 'wpify-erp' ),
					'post_type' => BookPostType::KEY,
				),
				array(
					'type'  => 'text',
					'id'    => 'note',
					'title' => __( 'Note', 'wpify-erp' ),
				),
			),
		) );
	}

	public function render( array $block_attributes, string $content ) {
		$book = $this->book_repository->get( $block_attributes['book'] );
		$note = $block_attributes['note'] ?? null;

		return $this->template->render( 'blocks/book', null, array(
			'note' => $note,
			'book' => $book,
		) );
	}
}
