<?php

namespace WpifyErp\Features;

use WpifyErp\Repositories\TaskCommentRepository;
use WpifyErp\Repositories\TaskRepository;
use WpifyErp\Repositories\UserRepository;


class Notifications {
	public function __construct(
		private Emails $emails,
		private UserRepository $user_repository,
		private TaskCommentRepository $comment_repository,
		private TaskRepository $task_repository
	) {
		add_action( 'wpify_erp_add_log', [ $this, 'trigger_notification' ], 10, 6 );
	}

	public function trigger_notification( $type, $object_id, $object_type, $log, $context, $original_item = null ) {
		if ( ( $object_type === 'task' && ! empty( $context['assigned_user_id'] ) && (
				$type === 'create' ||
				( $type === 'update' && ! empty( $original_item ) && $original_item->assigned_user_id !== $context['assigned_user_id'] )

			) ) ) {
			$user = $this->user_repository->get( $context['assigned_user_id'] );
			$this->emails->send_email(
				$user->email,
				'You have been assigned',
				[
					'preheader' => 'You have been assigned to a task.',
					'content'   => [
						[
							'type'    => 'text',
							'content' => '<p>You have been assigned to a task.</p>',
						],
						[
							'type'  => 'cta',
							'url'   => site_url( '#/task/' . $context['id'] ),
							'label' => 'Check it out',
						],
					],
				],
			);
		}
		if ( $type === 'create' && $object_type === 'comment' && ! empty( $context['description'] ) ) {
			$ids     = $this->extract_ids( $context['description'] );
			$comment = $this->comment_repository->get( $object_id );
			$task    = $this->task_repository->get( $comment->task_id );
			if ( $ids ) {
				foreach ( $ids as $id ) {
					$user = $this->user_repository->get( $id );
					$this->emails->send_email(
						$user->email,
						sprintf( 'You have been mentioned in a comment for task %s', $task->title ),
						[
							'preheader' => 'You have been mentioned in a comment.',
							'content'   => [
								[
									'type'    => 'text',
									'content' => '<p>You have been mentioned the following comment:</p>',
								],
								[
									'type'    => 'text',
									'content' => '<i>' . $context['description'] . '</i>',
								],
								[
									'type'  => 'cta',
									'url'   => site_url( '#/task/' . $context['id'] ),
									'label' => 'Check the task',
								],
							],
						],
					);
				}
			}

			if ( ! empty( $task->context['email_from'] ) ) {
				$this->emails->send_email(
					$task->context['email_from'],
					sprintf( 'Re: %s', $task->title ),
					[
						'preheader' => 'A new message has been added to your support ticket.',
						'content'   => [
							[
								'type'    => 'text',
								'content' => '<p>A new message has been added:</p>',
							],
							[
								'type'    => 'text',
								'content' => '<i>' . $context['description'] . '</i>',
							],
							[
								'type'    => 'text',
								'content' => '<p>You can reply directly to this email.</p>',
							],
							[
								'type'    => 'text',
								'content' => sprintf( '<p>----%s----</p>', $task->id ),
							],
						],
					],
				);
			}
		}
	}

	public function extract_ids( $input ) {
		$pattern = '/@.*?\((\d+)\)/'; // Match "@" followed by any characters and then ID in parentheses
		preg_match_all( $pattern, $input, $matches );
		if ( isset( $matches[1] ) ) {
			return $matches[1]; // Return the captured numbers
		} else {
			return []; // Return an empty array if no matches found
		}
	}
}
