<?php

namespace WpifyErp;

use WpifyErpDeps\Wpify\Asset\AssetFactory;
use WpifyErpDeps\Wpify\PluginUtils\PluginUtils;

class Frontend {
	/** @var PluginUtils */
	private $utils;

	/** @var AssetFactory */
	private $asset_factory;

	public function __construct(
		PluginUtils $utils,
		AssetFactory $asset_factory
	) {
		$this->utils         = $utils;
		$this->asset_factory = $asset_factory;

		$this->setup();
		$this->setup_assets();
	}

	public function setup() {
		add_action( 'template_redirect', function () {
			if ( ( is_single() || is_front_page() || is_page() )
				 && ! is_page( 'login' ) && ! is_user_logged_in() ) {
				auth_redirect();
			}
		} );
		add_shortcode( 'wpify_erp', function () {
			ob_start(); ?>
			<div data-app="wpify-erp"></div>
			<?php
			return ob_get_clean();
		} );
		add_action( 'after_setup_theme', [ $this, 'remove_admin_bar' ] );
	}

	public function setup_assets() {
		$this->asset_factory->wp_script( $this->utils->get_plugin_path( 'build/erp.js' ), array(
			'in_footer'     => true,
			'variables'     => array( 'erp' => array( 'nonce' => wp_create_nonce( 'wp_rest' ), ) ),
			'script_before' => 'console.log("script before plugin")',
			'script_after'  => 'console.log("script after plugin")',
		) );
		$this->asset_factory->wp_script( $this->utils->get_plugin_path( 'build/erp.css' ) );
	}

	function remove_admin_bar() {
		show_admin_bar( false );
	}
}
