<?php
// phpcs:ignore

namespace WpifyErp\Models;

use WpifyErp\Repositories\TaskCommentRepository;
use WpifyErpDeps\Wpify\Model\Attributes\Column;
use WpifyErpDeps\Wpify\Model\Attributes\ReadOnlyProperty;
use WpifyErpDeps\Wpify\Model\Model;

/**
 * Event model.
 */
class TaskModel extends Model {
	#[Column( type: Column::INT, auto_increment: true, primary_key: true )]
	public int $id = 0;

	#[Column( type: Column::VARCHAR, params: 255 )]
	public string $title = '';

	#[Column( type: Column::VARCHAR, params: 10000000 )]
	public string $description = '';

	#[Column( type: Column::VARCHAR, params: 255 )]
	public string $status = '';

	#[Column( type: Column::TIMESTAMP, nullable: false, default: 'NOW()' )]
	public ?string $date_created = null;

	#[Column( type: Column::TIMESTAMP, nullable: true )]
	public ?string $due_date = null;


	#[Column( type: Column::TIMESTAMP, on_update: 'CURRENT_TIMESTAMP' )]
	public string $date_updated = '';

	#[Column( type: Column::INT )]
	public int $user_id = 0;
	#[Column( type: Column::INT )]
	public int $assigned_user_id = 0;

	#[Column( type: Column::INT )]
	public int $project_id = 0;

	#[Column( type: Column::INT )]
	public int $order_index = 0;

	#[ReadOnlyProperty]
	public array $comments = [];

	#[ReadOnlyProperty]
	public array $time_entries = [];

	#[ReadOnlyProperty]
	public array $attachments = [];

	#[Column( type: Column::INT )]
	public int $client_id = 0;
	#[Column( type: Column::TIMESTAMP, nullable: true )]
	public ?string $deleted_at = null;

	#[ReadOnlyProperty]
	public ?ProjectModel $project;

	#[ReadOnlyProperty]
	public ?ClientModel $client;

	#[ReadOnlyProperty]
	public array $tags = [];

	#[ReadOnlyProperty]
	public ?string $permission_role = null;

	#[Column( type: Column::INT )]
	public int $internal = 0;

	#[Column( type: Column::INT )]
	public int $private = 0;

	#[Column( type: Column::JSON )]
	public array $context = [];

	#[Column( type: Column::JSON )]
	public array $checklist = [];


	public function to_array( array $props = array(), array $recursive = array() ): array {
		$data = parent::to_array( $props, [ 'comments', 'time_entries', 'attachments', 'project', 'client', 'tags' ] );

		return $data;
	}

	public function get_comments() {
		return $this->manager()->get_model_repository( TaskCommentModel::class )->find(
			[
				'where' => [
					"task_id = $this->id",
				],
			]
		);
	}

	public function get_time_entries() {
		return $this->manager()->get_model_repository( TimeEntryModel::class )->find(
			[
				'where' => [
					"task_id = $this->id",
				],
			]
		);
	}

	public function get_attachments() {
		return $this->manager()->get_model_repository( AttachmentModel::class )->find(
			[
				'where' => [
					"object_id = $this->id",
					'object_type = "task"',
				],
			]
		);
	}

	public function get_project() {
		return $this->project_id ? $this->manager()->get_model_repository( ProjectModel::class )->get( $this->project_id ) : null;
	}

	public function get_client() {
		return $this->client_id ? $this->manager()->get_model_repository( ClientModel::class )->get( $this->client_id ) : null;
	}

	public function get_tags() {
		return $this->manager()->get_model_repository( TagModel::class )->get_by_id_and_object_type( $this->id, 'task' );
	}

	public function get_permission_role() {
		$repo        = $this->manager()->get_model_repository( PermissionModel::class );
		$permissions = $repo->get_user_permissions();

		if ( $this->user_id === get_current_user_id() ) {
			return 'manager';
		}

		$found_roles = [];
		foreach ( $permissions as $permission ) {
			if ( ! empty( $permission['context']['modules']['task']['role'] ) ) {
				$found_roles[] = $permission['context']['modules']['task']['role'];
			} elseif ( 'project' === $permission['object_type'] && $permission['object_id'] === $this->project_id ) {
				$found_roles[] = $permission['role'];
			} elseif ( 'client' === $permission['object_type'] && $permission['object_id'] === $this->client_id ) {
				$found_roles[] = $permission['role'];
			}
		}
		if ( empty( $found_roles ) ) {
			return null;
		}

		return $repo->get_highest_role( $found_roles );
	}

}
