<?php
// phpcs:ignore

namespace WpifyErp\Models;

use WpifyErpDeps\Wpify\Model\Attributes\Column;
use WpifyErpDeps\Wpify\Model\Attributes\ReadOnlyProperty;
use WpifyErpDeps\Wpify\Model\Model;

/**
 * Event model.
 */
class TimeEntryModel extends Model {
	#[Column( type: Column::INT, auto_increment: true, primary_key: true )]
	public int $id = 0;

	#[Column( type: Column::INT, params: 255 )]
	public int $task_id = 0;

	#[Column( type: Column::INT, params: 255 )]
	public int $project_id = 0;

	#[Column( type: Column::INT, params: 255 )]
	public int $client_id = 0;

	#[Column( type: Column::INT, params: 255 )]
	public int $minutes = 0;

	#[Column( type: Column::VARCHAR, params: 255 )]
	public string $description = '';
	#[Column( type: Column::INT )]
	public int $user_id = 0;

	#[Column( type: Column::TIMESTAMP )]
	public string $date_start = '';

	#[Column( type: Column::TIMESTAMP, nullable: false, default: 'NOW()' )]
	public ?string $date_created = null;
	#[Column( type: Column::TIMESTAMP, on_update: 'CURRENT_TIMESTAMP' )]
	public string $date_updated = '';

	#[Column( type: Column::INT )]
	public int $internal = 0;

	#[Column( type: Column::INT )]
	public int $private = 0;

	#[Column( type: Column::TIMESTAMP, nullable: true )]
	public ?string $deleted_at = null;

	#[ReadOnlyProperty]
	public ?UserModel $user;

	#[ReadOnlyProperty]
	public ?ProjectModel $project;

	#[ReadOnlyProperty]
	public ?TaskModel $task;

	#[ReadOnlyProperty]
	public ?ClientModel $client;

	#[ReadOnlyProperty]
	public array $tags = [];


	public function to_array( array $props = array(), array $recursive = array() ): array {
		$data = parent::to_array( $props, [ 'user', 'project', 'client', 'tags' ] );

		if ( $data['task'] ) {
			$data['task'] = $data['task']->to_array( [ 'id', 'title', 'description', 'status' ] );
		}

		return $data;
	}

	public function get_user() {
		return $this->manager()->get_model_repository( UserModel::class )->get( $this->user_id );
	}

	public function get_project() {
		return $this->project_id ? $this->manager()->get_model_repository( ProjectModel::class )->get( $this->project_id ) : null;
	}

	public function get_task() {
		return $this->task_id ? $this->manager()->get_model_repository( TaskModel::class )->get( $this->task_id ) : null;
	}

	public function get_client() {
		return $this->client_id ? $this->manager()->get_model_repository( ClientModel::class )->get( $this->client_id ) : null;
	}

	public function get_tags() {
		$relationsships = $this->manager()->get_model_repository( TagRelationshipModel::class )->find(
			[
				'where' => [
					"object_id = $this->id",
					'object_type = "time_entry"',
				],
			]
		);

		if ( empty( $relationsships ) ) {
			return [];
		}

		return $this->manager()->get_model_repository( TagModel::class )->find(
			[
				'where' => [
					sprintf( "id IN (%s)",
					         implode( ',',
					                  array_map( function ( $item ) {
						                  return $item->tag_id;
					                  }, $relationsships ) ) ),
				],
			]
		);
	}


}
