<?php

namespace WpifyErp\Repositories;

use WpifyErp\Abstracts\AbstractRepository;
use WpifyErp\Models\ClientModel;
use WpifyErpDeps\Wpify\Model\CustomTableRepository;
use WpifyErpDeps\Wpify\Model\Exceptions\SqlException;
use WpifyErpDeps\Wpify\Model\Interfaces\ModelInterface;

/**
 * @method ClientModel create()
 */
class ClientRepository extends AbstractRepository {

	/**
	 * Table name.
	 * @var string $table_name
	 */
	public static string $table_name = 'wpify_erp_clients';

	/**
	 * Return table name.
	 * @return string
	 */
	public function table_name(): string {
		return self::$table_name;
	}

	public function model(): string {
		return ClientModel::class;
	}

	public function apply_permissions( array $args ) {
		$permissions = $this->get_user_permissions();

		$ids = [];
		foreach ( $permissions as $permission ) {
			if ( 'client' === $permission['object_type'] ) {
				$ids[] = $permission['object_id'];
			}
		}

		if ( ! empty( $ids ) ) {
			$args['where'][] = [
				'id' => $ids,
			];;
		} elseif ( ! current_user_can( 'administrator' ) ) {
			$args['where'][] = [
				"id" => null
			];
		}

		return $args;
	}
}
