<?php

namespace WpifyErp\Repositories;


use WpifyErp\Abstracts\AbstractRepository;
use WpifyErp\Models\PermissionModel;
use WpifyErp\Models\ProjectModel;

class PermissionRepository extends AbstractRepository {
	private $permissions = [];
	/**
	 * Table name.
	 * @var string $table_name
	 */
	public static string $table_name = 'wpify_erp_permissions';

	/**
	 * Return table name.
	 * @return string
	 */
	public function table_name(): string {
		return self::$table_name;
	}

	public function model(): string {
		return PermissionModel::class;
	}

	public function find( array $args = array() ): array {
		$defaults = array(
			'where' => array(),
		);

		$args = wp_parse_args( $args, $defaults );
		if ( is_string( $args['where'] ) ) {
			$args['where'] = array( $args['where'] );
		}
		$args['where'][] = 'deleted_at IS NULL';

		return get_parent_class( get_parent_class( $this ) )::find( $args );
	}

	public function get_user_permissions( int $user_id = 0 ) {
		if ( ! $user_id ) {
			$user_id = get_current_user_id();
		}

		if ( isset( $this->permissions[ $user_id ] ) ) {
			return $this->permissions[ $user_id ];
		}

		$args = [
			'where' => [
				"user_id = $user_id",
			],
		];

		$fake_permissions = [];
		$permissions      = $this->find( $args );
		$permissions      = array_map( fn( $item ) => $item->to_array(), $permissions );
		$found_ids        = [];
		foreach ( $permissions as $permission ) {
			$found_ids[] = $permission['object_type'] . $permission['object_id'];
		}

		$found_ids = array_map( fn( $item ) => $item['object_id'], $permissions );
		foreach ( $permissions as $permission ) {
			if ( 'client' === $permission['object_type'] ) {
				$table       = $this->manager()->get_model_repository( ProjectModel::class )->prefixed_table_name();
				$project_ids = $this->db()->get_col( "SELECT id FROM $table WHERE client_id = {$permission['object_id']}" );
				foreach ( $project_ids as $project_id ) {
					$fake_permissions[] = array_merge( $permission, [
						'object_type' => 'project',
						'object_id'   => $project_id,
					] );
				}
			}
			if ( 'project' === $permission['object_type'] ) {
				$table      = $this->manager()->get_model_repository( ProjectModel::class )->prefixed_table_name();
				$client_ids = $this->db()->get_col( "SELECT client_id FROM $table WHERE id = {$permission['object_id']} and client_id <>''" );
				foreach ( $client_ids as $client_id ) {
					$fake_permissions[] = array_merge( $permission, [
						'role'        => 'reader',
						'object_type' => 'client',
						'object_id'   => $client_id,
					] );
				}
			}
		}

		foreach ( $fake_permissions as $fake_permission ) {
			$id = $fake_permission['object_type'] . $fake_permission['object_id'];
			if ( ! in_array( $id, $found_ids ) ) {
				$permissions[] = $fake_permission;
			}
		}

		return $permissions;
	}


	public function build_args( array $args, $request ) {
		$result = [
			'where' => [],
		];

		if ( ! empty( $args['object_id'] ) ) {
			$result['where'][] = [
				'object_id' => $args['object_id'],
			];
		}
		if ( ! empty( $args['object_type'] ) ) {
			$result['where'][] = [
				'object_type' => $args['object_type'],
			];
		}

		return $result;
	}
	public function get_highest_role( array $roles ) {
		if ( in_array( 'manager', $roles ) ) {
			return 'manager';
		}
		if ( in_array( 'editor', $roles ) ) {
			return 'editor';
		}

		return 'reader';
	}
}
