<?php

namespace WpifyErp\Repositories;

use WpifyErp\Abstracts\AbstractRepository;
use WpifyErp\Models\ProjectModel;
use WpifyErpDeps\Wpify\Model\CustomTableRepository;

/**
 * @method ProjectModel create()
 */
class ProjectRepository extends AbstractRepository {

	/**
	 * Table name.
	 * @var string $table_name
	 */
	public static string $table_name = 'wpify_erp_projects';

	/**
	 * Return table name.
	 * @return string
	 */
	public function table_name(): string {
		return self::$table_name;
	}

	public function model(): string {
		return ProjectModel::class;
	}

	public function build_args( array $args, \WP_REST_Request $request ) {
		$result = [
			'where' => [],
		];
		if ( $request->get_method() === \WP_REST_Server::READABLE && ! empty( $args['client_id'] ) ) {
			$result['where'][] = 'client_id = ' . $request->get_param( 'client_id' );
		}

		return $result;
	}

	public function apply_permissions( array $args ) {
		$permissions = $this->get_user_permissions();
		$client_ids  = [];
		$project_ids = [];

		foreach ( $permissions as $permission ) {
			if ( 'client' === $permission['object_type'] ) {
				$client_ids[] = $permission['object_id'];
			}
			if ( 'project' === $permission['object_type'] ) {
				$project_ids[] = $permission['object_id'];
			}
		}

		if ( ! empty( $client_ids ) ) {
			$args['where'][] = [
				'client_id' => $client_ids,
			];
		}
		if ( ! empty( $project_ids ) ) {
			$args['where'][] = [
				'id' => $project_ids,
			];
		}

		if (!current_user_can('administrator') && empty($project_ids) && empty($client_ids)) {
			$args['where'][] = [
				"id" => null
			];
		}

		return $args;
	}
}
