<?php

namespace WpifyErp\Repositories;

use WpifyErp\Abstracts\AbstractRepository;
use WpifyErp\Models\ProjectModel;
use WpifyErp\Models\TaskModel;
use WpifyErpDeps\Wpify\Model\CustomTableRepository;
use WpifyErpDeps\Wpify\Model\Interfaces\ModelInterface;

/**
 * @method TaskModel create()
 * @method TaskModel get( mixed $source )
 */
class TaskRepository extends AbstractRepository {

	/**
	 * Table name.
	 * @var string $table_name
	 */
	public static string $table_name = 'wpify_erp_tasks';

	/**
	 * Return table name.
	 * @return string
	 */
	public function table_name(): string {
		return self::$table_name;
	}

	public function model(): string {
		return TaskModel::class;
	}

	public function build_args( array $args, $request ) {
		$result = [
			'where' => [],
		];
		if ( ! empty( $args['current_user'] ) ) {
			$result['where'][] = sprintf( 'user_id = %d OR assigned_user_id = %s', get_current_user_id(), get_current_user_id() );
		}

		if ( ! empty( $args['project_id'] ) ) {
			$result['where'][] = [
				'project_id' => $args['project_id'],
			];
		}
		if ( ! empty( $args['client_id'] ) ) {
			$result['where'][] = [
				'client_id' => $args['client_id'],
			];
		}
		if ( ! empty( $args['status'] ) ) {
			$result['where'][] = [
				'status' => $args['status']
			];
		}

		if ( ! empty( $args['status_not'] ) ) {
			$result['where'][] = [
				'status <>' => $args['status_not'],
			];
		}

		return $result;
	}

	public function apply_permissions( array $args ) {
		$permissions = $this->get_user_permissions();
		$client_ids  = [];
		$project_ids = [];

		foreach ( $permissions as $permission ) {
			if ( 'client' === $permission['object_type'] ) {
				if ( ! empty( $permission['context']['modules']['time_entry']['role'] ) && $permission['context']['modules']['task']['role'] === 'none' ) {
					continue;
				}
				$client_ids[] = $permission['object_id'];
			}
			if ( 'project' === $permission['object_type'] ) {
				if ( ! empty( $permission['context']['modules']['time_entry']['role'] ) && $permission['context']['modules']['task']['role'] === 'none' ) {
					continue;
				}

				$project_ids[] = $permission['object_id'];
			}
		}
		$query_args = [
			'user_id' => get_current_user_id(),
		];
		if ( ! empty( $client_ids ) ) {
			$query_args[] = 'or';
			$query_args[] = [
				'client_id' => $client_ids,
			];
		}
		if ( ! empty( $project_ids ) ) {
			$query_args[] = 'or';
			$query_args[] = [
				'project_id' => $project_ids,
			];
		}
		if ( ! empty( $query_args ) ) {
			$args['where'][] = $query_args;
		}

		return $args;
	}
}
