<?php

namespace WpifyErp\Repositories;

use WpifyErp\Abstracts\AbstractRepository;
use WpifyErp\Models\TimeEntryModel;

/**
 * @method TimeEntryModel create()
 */
class TimeEntryRepository extends AbstractRepository {

	/**
	 * Table name.
	 * @var string $table_name
	 */
	public static string $table_name = 'wpify_erp_time_entries';

	/**
	 * Return table name.
	 * @return string
	 */
	public function table_name(): string {
		return self::$table_name;
	}

	public function model(): string {
		return TimeEntryModel::class;
	}

	public function build_args( array $args ) {
		$result = [
			'where' => [],
		];
		if ( ! empty( $args['date_from'] ) ) {
			$result['where'][] = 'date_start >= "' . $args['date_from'] . '"';
		}
		if ( ! empty( $args['date_to'] ) ) {
			$result['where'][] = 'date_start <= "' . $args['date_to'] . '"';
		}
		if ( ! empty( $args['current_user'] ) ) {
			$result['where'][] = sprintf( 'user_id = %d', get_current_user_id() );
		}
		if ( ! empty( $args['task_id'] ) ) {
			$result['where']['task_id'] = $args['task_id'];
		}


		return $result;
	}

	public function apply_permissions( array $args ) {
		$permissions = $this->get_user_permissions();
		$client_ids  = [];
		$project_ids = [];

		foreach ( $permissions as $permission ) {
			if ( 'client' === $permission['object_type'] ) {
				if ( ! empty( $permission['context']['modules']['time_entry']['role'] ) && $permission['context']['modules']['time_entry']['role'] === 'none' ) {
					continue;
				}
				$client_ids[] = $permission['object_id'];
			}
			if ( 'project' === $permission['object_type'] ) {
				if ( ! empty( $permission['context']['modules']['time_entry']['role'] ) && $permission['context']['modules']['time_entry']['role'] === 'none' ) {
					continue;
				}

				$project_ids[] = $permission['object_id'];
			}
		}

		$query_args = [
			'user_id' => get_current_user_id(),
		];
		if ( ! empty( $client_ids ) ) {
			$query_args[] = 'or';
			$query_args[] = [
				'client_id' => $client_ids,
			];
		}
		if ( ! empty( $project_ids ) ) {
			$query_args[] = 'or';
			$query_args[] = [
				'project_id' => $project_ids,
			];
		}
		if ( ! empty( $query_args ) ) {
			$args['where'][] = $query_args;
		}

		return $args;
	}
}
