module.exports = {
	important: true,
	darkMode: 'class',
	content: [
		'./src/**/*.php',
		'./assets/**/*.jsx',
		'./assets/**/*.js',
		'./assets/**/*.pcss',
		'./assets/**/*.scss'
	],
	theme: {
		screens: {
			xs: '414px',
			sm: '640px',
			md: '768px',
			lg: '1024px',
			xl: '1280px',
		},
		fontFamily: {
			'noto-sans': ['Noto Sans', 'sans-serif'],
			'fira-sans': ['"Fira Sans"'],
			'cormorant': ['Cormorant Garamond'],
		},
		extend: {
			boxShadow: {
				'3xl': '0 0 20px 0 rgba(0, 0, 0, 0.1)',
			},

			dropShadow: {
				'3xl': '0 0 10px rgba(0, 0, 0, 0.5)',
			},

			transitionDuration: {
				DEFAULT: '300ms',
			},

			typography: (theme) => ({
				DEFAULT: {
					css: {
						'--tw-prose-body': theme('colors.primary'),
						'--tw-prose-headings': theme('colors.primary'),
						'--tw-prose-hr': theme('colors.primary'),
						'--tw-prose-captions': theme('colors.gray.500'),
						'--tw-prose-bullets': theme('colors.primary'),
						'--tw-prose-quote-borders': theme('colors.beige.DEFAULT'),
						'--tw-prose-counters': theme('colors.primary'),
						fontFamily: theme('fontFamily.noto-sans'),
						maxWidth: 'none',
						p: {
							marginTop: '1rem',
							lineHeight: '1.6em',
							letterSpacing: '0.8px',
						},
						a: {
							color: theme('colors.green.300'),
							fontWeight: 'inherit',
							textDecoration: 'underline',
						},
						'a:hover': {
							textDecoration: 'none',
						},
						'b,strong': {
							color: 'inherit',
						},
						hr: {
							marginTop: '0.5em',
							marginBottom: '0.5em',
						},
						ul: {
							marginBottom: '1.5em',
						},
						p: {
							lineHeight: '1.625em',
							marginBottom: '1.25em',
						},
						h1: {
							fontSize: '2.5rem',
							textAlign: 'center',
							fontWeight: '400',
							marginBottom: '10px',
							fontFamily: 'Noto Sans',
						},
						h2: {
							fontSize: '1.875rem',
							marginTop: '1em',
							fontWeight: '400',
							fontFamily: 'Noto Sans',
						},
						h3: {
							fontWeight: '400',
							fontFamily: 'Noto Sans',
						},
						h4: {
							fontWeight: '400',
							fontFamily: 'Noto Sans',
						},
						h5: {
							fontWeight: '400',
							fontFamily: 'Noto Sans',
						},
						blockquote: {
							quotes: 'none',
							fontStyle: 'normal',
							borderLeftWidth: '10px',
						},
						'blockquote p': {
							fontSize: '1.5rem',
							lineHeight: '1.35em',
							fontFamily: 'Noto Sans',
						},
						figcaption: {
							textAlign: 'center',
							fontSize: '1.1rem',
							letterSpacing: '1px',
							fontFamily: 'Noto Sans',
						},
						'figure img': {
							marginTop: '0rem',
							marginBottom: '1rem',
						},
						'wp-block-image img': {
							marginLeft: 'auto',
							marginRight: 'auto',
						},
					},
				},
				md: {
					css: {
						h1: {
							fontSize: '3em',
						},
						h2: {
							fontSize: '2em',
						},
						'blockquote p': {
							fontSize: '1.875rem',
						},
					},
				},
			}),
			spacing: {
				0: '0',
				px: '1px',
				'2px': '2px',
				'5vw': '5vw',
				'6vw': '6vw',
				7: '1.75rem',
				14: '3.5rem',
				15: '3.75rem',
				18: '4.5rem',
				28: '7rem',
				30: '7.5rem',
				36: '9rem',
				40: '10rem',
				44: '11rem',
				48: '12rem',
				52: '13rem',
				56: '14rem',
				60: '15rem',
				64: '16rem',
				68: '17rem',
				72: '18rem',
				84: '21rem',
				112: '28rem',
				128: '32rem',
				160: '40rem',
				192: '48rem',
				240: '60rem',
				256: '64rem',
				280: '70rem',
				300: '75rem',
				384: '96rem',
				512: '128rem',
				560: '140rem',
				600: '150rem',
				768: '192rem',
				'110vw': '110vw',
			},

			minHeight: (theme) => ({
				...theme('spacing'),
			}),

			cursor: {
				grab: 'grabbing',
			},

			colors: {
				primary: '#1D2F28',
				beige: {
					50: '#FFFCFA',
					100: '#FEF0E5',
					200: '#efe0d2',
					DEFAULT: '#FCB37F',
					500: '#FCBC86',
					600: '#CB8342',
					700: '#B1641E',
					800: '#AC8B66',
				},
				green: {
					300: '#65957e',
					400: '#2FBB78',
					DEFAULT: '#2f5647',
				},
				blue: {
					DEFAULT: '#2696BF',
				},
				gray: {
					100: '#EFEFEF',
					DEFAULT: '#666666',
					500: '#999999',
				},
				red: {
					300: '#EA4335',
					400: '#D02424',
					DEFAULT: '#CA1F23',
				},
			},
			zIndex: {
				'-10': '-10',
			},
			padding: (theme) => ({
				...theme('width'),
				'ar-10/1': '10%',
				'ar-25/5': '20%',
				'ar-25/7': '28%',
				'ar-24/7': '29%',
				'ar-25/9': '36%',
				'ar-23/9': '39.13%',
				'ar-21/9': '42.857%',
				'ar-1/2': '50%',
				'ar-16/9': '56.25%',
				'ar-17/9': '52.94%',
				'ar-16/10': '62.5%',
				'ar-7/10': '70%',
				'ar-4/3': '75%',
				'ar-square': '100%',
				'ar-3/4': '133.333%',
				'ar-9/16': '177.77%',
				'ar-10/16': '160%',
				'ar-10/25': '250%',
			}),
		},
	},
	variants: {},
	plugins: [
		require('@tailwindcss/typography'),
	],
	corePlugins: {
		container: false,
		preflight: false,
	},
};
