<?php
/*
 * Plugin Name:       Wpify ERP
 * Description:       Plugin skeleton with theme by WPify
 * Version:           1.0.0
 * Requires PHP:      7.3.0
 * Requires at least: 5.3.0
 * Author:            WPify
 * Author URI:        https://www.wpify.io/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       wpify-erp
 * Domain Path:       /languages
*/

use WpifyErp\Plugin;
use WpifyErpDeps\DI\Container;
use WpifyErpDeps\DI\ContainerBuilder;

if ( ! defined( 'WPIFY_ERP_MIN_PHP_VERSION' ) ) {
	define( 'WPIFY_ERP_MIN_PHP_VERSION', '7.3.0' );
}

/**
 * @return Plugin
 * @throws Exception
 */
function wpify_erp(): Plugin {
	return wpify_erp_container()->get( Plugin::class );
}

/**
 * @return Container
 * @throws Exception
 */
function wpify_erp_container(): Container {
	static $container;

	if ( empty( $container ) ) {
		$is_production    = ! WP_DEBUG;
		$file_data        = get_file_data( __FILE__, array( 'version' => 'Version' ) );
		$definition       = require_once __DIR__ . '/config.php';
		$containerBuilder = new ContainerBuilder();
		$containerBuilder->addDefinitions( $definition );

		$container = $containerBuilder->build();
	}

	return $container;
}

function wpify_erp_activate( $network_wide ) {
	wpify_erp()->activate( $network_wide );
}

function wpify_erp_deactivate( $network_wide ) {
	wpify_erp()->deactivate( $network_wide );
}

function wpify_erp_uninstall() {
	wpify_erp()->uninstall();
}

function wpify_erp_php_upgrade_notice() {
	$info = get_plugin_data( __FILE__ );

	echo sprintf(
		__( '<div class="error notice"><p>Opps! %s requires a minimum PHP version of %s. Your current version is: %s. Please contact your host to upgrade.</p></div>', 'wpify-erp' ),
		$info['Name'],
		WPIFY_ERP_MIN_PHP_VERSION,
		PHP_VERSION
	);
}

function wpify_erp_php_vendor_missing() {
	$info = get_plugin_data( __FILE__ );

	echo sprintf(
		__( '<div class="error notice"><p>Opps! %s is corrupted it seems, please re-install the plugin.</p></div>', 'wpify-erp' ),
		$info['Name']
	);
}

if ( version_compare( PHP_VERSION, WPIFY_ERP_MIN_PHP_VERSION ) < 0 ) {
	add_action( 'admin_notices', 'wpify_erp_php_upgrade_notice' );
} else {
	$deps_loaded   = false;
	$vendor_loaded = false;

	$deps = array_filter( array( __DIR__ . '/deps/scoper-autoload.php', __DIR__ . '/deps/autoload.php' ), function ( $path ) {
		return file_exists( $path );
	} );

	foreach ( $deps as $dep ) {
		include_once $dep;
		$deps_loaded = true;
	}

	if ( file_exists( __DIR__ . '/vendor/autoload.php' ) ) {
		include_once __DIR__ . '/vendor/autoload.php';
		$vendor_loaded = true;
	}
	require_once __DIR__ . '/src/helpers.php';

	if ( $deps_loaded && $vendor_loaded ) {
		add_action( 'plugins_loaded', 'wpify_erp', 11 );
		register_activation_hook( __FILE__, 'wpify_erp_activate' );
		register_deactivation_hook( __FILE__, 'wpify_erp_deactivate' );
		register_uninstall_hook( __FILE__, 'wpify_erp_uninstall' );
	} else {
		add_action( 'admin_notices', 'wpify_erp_php_vendor_missing' );
	}
}
